@@ -35,14 +35,25 @@
 
 extern void print_menu_equilib (world_fmt * world);
 extern int myID;
+// functions
+void autotune_proposal(world_fmt *world, long which);
+void present_burnin_info(world_fmt *world, MYREAL ess, MYREAL acceptance, MYREAL var, MYREAL oldvar,  long step);
+MYREAL mean_acceptance_rate(world_fmt * world);
+MYINLINE boolean auto_stop_burnin(world_fmt *world,  long step,  long stop, MYREAL * var, MYREAL *autocorrelation, MYREAL * effective_sample);
+long  expected_end_burnin(world_fmt *world, MYREAL percent, long starttime, char *text);
+void burnin_progress(MYREAL percent);
+void burnin_bayes(world_fmt * world);
+void burnin_chain (world_fmt * world);
 
+
+// functions implementation
 void autotune_proposal(world_fmt *world, long which)
 {
     MYREAL ratio;
     worldoption_fmt *wopt = world->options;
     bayes_fmt *bayes = world->bayes;
     MYREAL *delta = bayes->delta;
-    long space = MAX(10,world->numpop2+1);
+    long space = MAX(10, (long) world->numpop2+1);
     const MYREAL ma = bayes->maxparam[which];
     const MYREAL mi = bayes->minparam[which];
     const MYREAL mindelta = (ma-mi)/1000.;
@@ -78,9 +89,9 @@ void autotune_proposal(world_fmt *world, long which)
     }
 }
 
-void present_burnin_info(world_fmt *world, MYREAL ess, MYREAL acceptance, MYREAL var, MYREAL oldvar, long step)
+void present_burnin_info(world_fmt *world, MYREAL ess, MYREAL acceptance, MYREAL var, MYREAL oldvar,  long step)
 {
-  long z=0;
+   long z=0;
 #ifdef MPI
     char p[LINESIZE];
     char p1[LINESIZE];
@@ -112,15 +123,15 @@ void present_burnin_info(world_fmt *world, MYREAL ess, MYREAL acceptance, MYREAL
 
 MYREAL mean_acceptance_rate(world_fmt * world)
 {
-  long which;
-  long i;
+   long which;
+   long i;
   bayes_fmt * bayes = world->bayes;
   MYREAL sum = 0.0;
   long count = 0;
   if (!world->options->bayes_infer)
     return -1.0;
 
-  for (i = 0; i <  world->numpop2 + bayes->mu; i++)
+  for (i = 0; i <  world->numpop2 + ( long) bayes->mu; i++)
     {
       if(shortcut(i,bayes,&which))
 	continue;
@@ -133,11 +144,11 @@ MYREAL mean_acceptance_rate(world_fmt * world)
   return sum/count;
 }
 
-MYINLINE boolean auto_stop_burnin(world_fmt *world, long step, long stop, MYREAL * var, MYREAL *autocorrelation, MYREAL * effective_sample, MYREAL *acceptances)
+MYINLINE boolean auto_stop_burnin(world_fmt *world,  long step,  long stop, MYREAL * var, MYREAL *autocorrelation, MYREAL * effective_sample)
 {
     char autostop = world->options->burnin_autostop;
-    const long delta = ((stop >= 10000) ? 1000 : (stop / 10));
-    const long nn = world->numpop2 + world->bayes->mu + 1 + world->species_model_size * 2 ;
+    const  long delta = ((stop >= 10000) ? 1000 : (stop / 10));
+    const  long nn = world->numpop2 + ( long) world->bayes->mu + 1 + world->species_model_size * 2 ;
     MYREAL oldvar= *var;
     MYREAL acceptance;
     MYREAL ess;
@@ -188,7 +199,7 @@ long  expected_end_burnin(world_fmt *world, MYREAL percent, long starttime, char
       {
 	mytime -= starttime;
 	//printf("burningtime: %li %li\n",starttime,mytime);
-	mytime = (long) (100 * mytime / (double) percent) * world->options->heated_chains;
+	mytime = (long) ((100 * mytime / (double) percent) * world->options->heated_chains);
 	get_time (nowstr, "%H:%M:%S");
 #ifdef MPI
 	FPRINTF(stdout, "[%3i] %s   %s in %li seconds\n",myID,nowstr, text, mytime); 
@@ -199,7 +210,7 @@ long  expected_end_burnin(world_fmt *world, MYREAL percent, long starttime, char
     return mytime;
 }
 
-void burnin_progress(world_fmt *world, MYREAL percent)
+void burnin_progress(MYREAL percent)
 {
     char nowstr[STRSIZE]; // will hold time of day
     get_time (nowstr, "%H:%M:%S");
@@ -216,14 +227,14 @@ void burnin_bayes(world_fmt * world)
 #ifndef MPI
   const boolean progress = world->options->progress && world->cold;
 #endif
-  const long stop = world->options->burn_in * world->increment;
-  const long nn = world->numpop2 + world->bayes->mu+ world->species_model_size * 2 ;
-  long delta = ((stop > 100000) ? (stop / 10) : (stop/3));
+  const  long stop = world->options->burn_in * world->increment;
+  const  long nn = world->numpop2 + ( long) world->bayes->mu+ world->species_model_size * 2 ;
+   long delta = ((stop > 100000) ? (stop / 10) : (stop/3));
   MYREAL * autocorrelation;
   MYREAL * effective_sample;
-  MYREAL * acceptances;
+  //MYREAL * acceptances;
   MYREAL var=HUGE;
-  long step;
+   long step;
   int choice;
   boolean success=FALSE;
   boolean done=FALSE;
@@ -234,9 +245,9 @@ void burnin_bayes(world_fmt * world)
   if(delta==0)
     delta=1;
 
-  autocorrelation  = (MYREAL *) calloc(3 + 3*nn,sizeof(MYREAL));
+  autocorrelation  = (MYREAL *) mycalloc((size_t) (3 + 3*nn),sizeof(MYREAL));
   effective_sample = autocorrelation + nn + 1;
-  acceptances      = effective_sample + nn + 1;
+  //acceptances      = effective_sample + nn + 1;
 
   single_chain_var (NULL, 0, &var, NULL, NULL);
   double r = -1.0 ; 
@@ -251,8 +262,7 @@ void burnin_bayes(world_fmt * world)
       if (!reportdone && progress && step % delta == 0)
 	{
 	  reportdone=TRUE;
-	  expected_end_burnin(world,100*(step-1)/stop, starttime, "Burn-in complete ");
-	  //burnin_progress(world,100*(step-1)/stop);
+	  expected_end_burnin(world,100*(step-1)/stop * world->options->heated_chains, starttime, "Burn-in complete ");
 	}
 #endif
       r = RANDUM();
@@ -264,14 +274,14 @@ void burnin_bayes(world_fmt * world)
       switch(choice)
 	{
 	case 0:
-	  success = tree_update (world, 0, NOASSIGNING);
+	  success = (boolean) tree_update (world, 0, NOASSIGNING);
 	  break;
 	case 1:
 	  world->bayesaccept = bayes_update (world);
 	  world->param_like = world->bayes->oldval;
 	  break;
 	case 2:
-	   success = swap_haplotypes(world);
+	  success = (boolean) swap_haplotypes(world);
 	  break;
 	case 3:
 	  // time update
@@ -279,7 +289,7 @@ void burnin_bayes(world_fmt * world)
 	  break;
 	case 4:
 	  // assignment of individuals
-	  success = tree_update (world, 0, ASSIGNING);
+	  success = (boolean) tree_update (world, 0, ASSIGNING);
 	  break;
 	case 5:
 	  change_freq(world);
@@ -289,7 +299,7 @@ void burnin_bayes(world_fmt * world)
 	}
 	        if((step % delta) == 0)
         {
-	  done = auto_stop_burnin(world, step, stop, &var, autocorrelation, effective_sample, acceptances);
+	  done = auto_stop_burnin(world, step, stop, &var, autocorrelation, effective_sample);
           }
 	if(done)
 	  break;
@@ -300,15 +310,14 @@ void burnin_bayes(world_fmt * world)
   myfree(autocorrelation);
 }
 
-void
-burnin_chain (world_fmt * world)
+void burnin_chain (world_fmt * world)
 {
   char autostop = world->options->burnin_autostop;
-  const long nng = world->numpop2 + world->bayes->mu + 1 + world->species_model_size * 2.0; //to set zero including the genealogy
-  const boolean treeprint = world->options->treeprint;
-    long z=0;
+  const  long nng = world->numpop2 + ( long) world->bayes->mu + 1 + world->species_model_size * 2; //to set zero including the genealogy
+  const boolean treeprint = (boolean) world->options->treeprint;
+     long z=0;
     world->burnin_z=0;        
-    world->options->treeprint = _NONE;
+    world->options->treeprint = myNONE;
     
     world->in_burnin = TRUE;
     if (world->cold)
@@ -316,8 +325,8 @@ burnin_chain (world_fmt * world)
         print_menu_equilib (world);
     }
     burnin_bayes(world);
-    memset(world->bayes->accept,0,sizeof(long)*nng);//Cesky Krumlov 2013
-    memset(world->bayes->trials,0,sizeof(long)*nng);//Cesky Krumlov 2013
+    memset(world->bayes->accept,0,sizeof(long) * (size_t) nng);//Cesky Krumlov 2013
+    memset(world->bayes->trials,0,sizeof(long) * (size_t) nng);//Cesky Krumlov 2013
     if (world->cold)
       {
 	z = world->burnin_z-1;
