@@ -81,7 +81,7 @@ extern void set_numind (data_fmt * data);
 extern long max_shuffled_individuals(option_fmt *options, data_fmt *data, long pop, long locus);
 
 extern long number_genomes (int type);
-extern void destroy_data(data_fmt * data, world_fmt *world);
+extern void destroy_data(data_fmt * data);
 
 extern void set_datatype_string(char datatype, char * dstring);
 extern void print_ratetbl (FILE * outfile, world_fmt * world, option_fmt * options,
