@@ -38,13 +38,26 @@ $Id: definitions.h 2170 2013-09-19 12:08:27Z beerli $
 *----------------------------------------------------------------
 */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "4.2.2a"
+#define MIGRATEVERSION "4.2.7"
 #endif
 #ifndef MIGRATESUBVERSION
-#define MIGRATESUBVERSION "July-18-15"
+#define MIGRATESUBVERSION "April-1-2016"
 #endif
 
 #define MAINTAINER "Peter Beerli <beerli@fsu.edu>"
+/* compiler directives */
+//#ifndef CLANG_ANALYZER_NORETURN
+//#if __has_feature(noreturn)
+#ifdef __clang__
+#define CLANG_ANALYZER_NORETURN __attribute__((noreturn))
+#else
+#define CLANG_ANALYZER_NORETURN
+#endif
+//#endif
+
+
+
+
 /*------------------------------------------------
   Adjusting the source to the system configuration
 */
@@ -63,9 +76,11 @@ $Id: definitions.h 2170 2013-09-19 12:08:27Z beerli $
 #ifdef HAVE_CONFIG_H
 #include "conf.h"
 #endif
+#ifdef HAVE_AVX
 #ifdef __AVX__
 #define AVX
 #endif
+#endif
 /* we don't want to have the sun specific define of "sun"*/
 #ifdef sun
 #undef sun
@@ -96,7 +111,7 @@ $Id: definitions.h 2170 2013-09-19 12:08:27Z beerli $
 //#undef HAVE_LGAMMA
 #define HAVE_STRFTIME 1
 //#define HIGHBITS
-// #define LAMARC_MALLOC
+// #define MIGRATE_MALLOC
 //#ifdef macintosh
 //    #define MAC
 //    #include <ansi_prefix.mac.h> /*fixes time problems */
@@ -106,7 +121,7 @@ $Id: definitions.h 2170 2013-09-19 12:08:27Z beerli $
 //    #undef HAVE_LGAMMA
 //    #define HAVE_STRFTIME 1
 //    #define HIGHBITS
-//    #define LAMARC_MALLOC
+//    #define MIGRATE_MALLOC
 //   #endif /*windows */
 //#endif /*MWERKS*/
 
@@ -239,7 +254,7 @@ $Id: definitions.h 2170 2013-09-19 12:08:27Z beerli $
 /*if we use this then we guard against allocation problems */
 /* redefinitions of calloc, malloc, realloc are in sighandler.h*/
 #ifdef HAVE_MALLOCWRAP
-#define LAMARC_MALLOC
+#define MIGRATE_MALLOC
 #endif
 
 #ifdef HAVE_DEBUGMPI
@@ -573,7 +588,7 @@ long chains is used */
 #define STOP                   1L
 #define CONT                   3L
 /* tree-print options */
-#define _NONE                   0 /*+ */
+#define myNONE                   0 /*+ */
 #define ALL                    1 /*+ */
 #define BEST                   2 /*+ */
 #define LASTCHAIN              3 /*+ */
@@ -641,7 +656,7 @@ long chains is used */
 #define SUCCESS 999
 #define FAILURE -888
 
-#ifndef LAMARC_MAC_INTERFACE
+#ifndef MIGRATE_MAC_INTERFACE
 #define eventloop() /* eventloop would go here */
 #endif
 
