@@ -55,7 +55,15 @@ extern int myID;
 #endif
 
 void setup_mig_coal_events (world_fmt * world, option_fmt * options);
-
+void minmax (histogram_fmt * hist, float *tempmin, float *tempmax);
+void destroy_mig_coal_events (world_fmt * world);
+void print_event_values_list(FILE *file, long locus, duo **eventbins, MYREAL eventbinsize, long *eventbinnum, world_fmt* world);
+void read_event_values_fromfile(FILE *file, world_fmt *world);
+void print_event_values_tofile(FILE *file,  world_fmt *world);
+void prepare_event_values(world_fmt *world, MYREAL *sums0,MYREAL *sums1);
+void print_event_values_title(FILE *file, boolean progress);
+void store_events (world_fmt * world, timelist_fmt * ltl, long np, long rep);
+//##
 ///
 /// allocates the necessary memory for recording of the events through time
 void
@@ -95,8 +103,7 @@ destroy_mighist (world_fmt * world)
       }
 }
 
-void
-minmax (histogram_fmt * hist, float *tempmin, float *tempmax)
+void minmax (histogram_fmt * hist, float *tempmin, float *tempmax)
 {
     long i;
     MYREAL tmp1, tmp2;
@@ -184,11 +191,11 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
       {
         eventbins = world->mighistloci[locus].migeventbins;
         eventbinnum = world->mighistloci[locus].migeventbinnum;
-        eventbinsize = world->mighistloci[locus].eventbinsize;
+        eventbinsize = (float) world->mighistloci[locus].eventbinsize;
         
         for (pop = startpop; pop < endpop; pop++)
           {
-            age = eventbinsize / 2.;
+            age = eventbinsize / 2.0f;
             values = (float *) myrealloc(values, eventbinnum[pop] * sizeof(float));
             
             lp = locus * npp + pop;
@@ -234,9 +241,9 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
         for (pop = startpop; pop < endpop; pop++)
           {
             lp = locus * npp + pop;
-            ntotal += sums[lp];
-            freq[lp] =  sums[lp];  
-            stdtime[lp] = sqrt(stdtime[lp]);
+            ntotal += (float) sums[lp];
+            freq[lp] =  (float) sums[lp];  
+            stdtime[lp] = (float) sqrt(stdtime[lp]);
           }
         for (pop = startpop; pop < endpop; pop++)
           {
@@ -257,7 +264,7 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
           {
             lp = sumloc * npp + pop;
             //mediantime[lp] = -1.; //DEBUG: allvalues[pop][(long) (eventbinnum[pop]/2)]/freq[lp];
-            stdtime[lp] = sqrt(stdtime[lp]);
+            stdtime[lp] = (float) sqrt(stdtime[lp]);
           }
       }
     
@@ -346,6 +353,7 @@ void calculate_event_values(duo **eventbins, long *eventbinnum, MYREAL eventinte
                             MYREAL interval, MYREAL age, char type, long from, long to, 
                             long * lineages, long numpop, boolean is_last, world_fmt *world)
 {
+  (void) lineages;
     MYREAL inv_eventinterval = 1. / eventinterval;
     long bin = (long) (age * inv_eventinterval); // this bin
                                                  //  long k;
@@ -411,6 +419,7 @@ void calculate_event_values(duo **eventbins, long *eventbinnum, MYREAL eventinte
 void
 setup_mig_coal_events (world_fmt * world, option_fmt * options)
 {
+  (void) options;
     long locus, i, j;
     long allocsize = 1;
     long npall = world->numpop2+ world->bayes->mu + world->species_model_size * 2;
@@ -442,8 +451,7 @@ setup_mig_coal_events (world_fmt * world, option_fmt * options)
 
 ///
 /// Destroy the event plot histogram container
-void
-destroy_mig_coal_events (world_fmt * world)
+void destroy_mig_coal_events (world_fmt * world)
 {
     long locus, i;
     long npall = world->numpop2  + world->bayes->mu + world->species_model_size * 2;
@@ -530,7 +538,7 @@ void read_event_values_fromfile(FILE *file, world_fmt *world)
   long npall = world->numpop2+world->species_model_size * 2 + world->bayes->mu;
 
   input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
-  allocsize = (long *) mycalloc(npall*world->loci,sizeof(long));
+  allocsize = (long *) mycalloc((npall*world->loci),sizeof(long));
   for(i=0;i<npall*world->loci;i++)
     {
       allocsize[i]=1;
@@ -562,8 +570,8 @@ void read_event_values_fromfile(FILE *file, world_fmt *world)
 	      allocsize[spacer + pop] += SOME_ELEMENTS;
 	      eventbins[pop] = (duo *) myrealloc(eventbins[pop],allocsize[spacer + pop] * sizeof(duo));
 	    }
-	  eventbins[pop][i][0] = atof(strsep(&inptr,"\t"));
-	  eventbins[pop][i][1] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][0] = (float) atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][1] = (float) atof(strsep(&inptr,"\t"));
 	}
     }
   myfree(allocsize);
@@ -795,7 +803,7 @@ void print_event_values(world_fmt * world)
     if(world->options->mighist)
       {
     
-	sums0 = (MYREAL *) mycalloc(world->loci * npall * 2,sizeof(MYREAL));
+	sums0 = (MYREAL *) mycalloc((world->loci * npall * 2),sizeof(MYREAL));
 	sums1 = sums0 + (world->loci * npall);
 
 	if(world->options->datatype != 'g')
@@ -848,9 +856,10 @@ void print_event_values(world_fmt * world)
 }
 
 /// store the event statistics
-void
-store_events (world_fmt * world, timelist_fmt * ltl, long np, long rep)
+void store_events (world_fmt * world, timelist_fmt * ltl, long np, long rep)
 {
+  (void) rep;
+  (void) np;
     long j;
     long T;
     MYREAL t;
