@@ -44,13 +44,12 @@ extern int pdf_init(void);
 // print title on every new page
 extern int pdf_new_page(char *title);
 // print master title on first page 
-extern int pdf_master_title(char *title, float *orig_page_height, float *orig_left_margin);
+extern int pdf_master_title(char *title);
 
 extern void pdf_print_end_time(float *page_height);
 // OPTIONS
 // print options onto the first page
-extern void pdf_print_options(world_fmt * world, option_fmt *options, data_fmt * data, 
-			      float *orig_page_height, float *orig_left_margin);
+extern void pdf_print_options(world_fmt * world, option_fmt *options, data_fmt * data);
 #ifdef BEAGLE
 extern void print_beagle_resources_pretty(BeagleInstanceDetails instDetails);
 #endif
@@ -61,7 +60,7 @@ extern void pdf_print_data_summary(world_fmt * world, option_fmt *options, data_
                               float *orig_page_height, float *orig_left_margin);
 extern void pdf_print_random_subset(data_fmt * data, option_fmt *options);
 // print data
-extern void pdf_print_data (world_fmt * world, option_fmt * options, data_fmt * data, float *orig_page_height, float *orig_left_margin);
+extern void pdf_print_data (world_fmt * world, option_fmt * options, data_fmt * data);
 extern void pdf_print_spectra(world_fmt *world, data_fmt *data, option_fmt *options, MYREAL ***freq, MYREAL ** total, MYREAL *grandtotal, MYREAL *avg_het, MYREAL avghet1, long * maxalleles);
 extern void pdf_print_averageheat(world_fmt **universe, option_fmt *options);
 
@@ -69,8 +68,8 @@ extern void pdf_print_averageheat(world_fmt **universe, option_fmt *options);
 // print bayes table
 extern void pdf_print_bayestable(world_fmt *world);
 // print histogram at location lx ly with widht and height
-extern void pdf_histogram(float *binvals, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, boolean nofreq, MYREAL *priors);
-extern void pdf_histogram_plus(float *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence, long topop);
+extern void pdf_histogram(double *binvals, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, boolean nofreq, MYREAL *priors);
+extern void pdf_histogram_plus(double *binvals, MYREAL *std, char *set50, char *set95, long bins, float bindelta, float binmin, float binmax, float lx, float ly, float width, float height, MYREAL scaler, boolean nofreq, world_fmt * world, float *confidence, long topop);
 // print histogram for each locus and overall loci
 extern float pdf_locus_histogram(world_fmt *world, long locus);
 extern float pdf_loci_histogram(world_fmt *world);
@@ -103,7 +102,7 @@ extern void pdf_skyline_histogram(long loci, long numparams,  world_fmt *world,
 // ML OUPUTS
 // print mcmc table
 //extern void pdf_print_mcmctable(float *page_height, float page_width, world_fmt *world, data_fmt *data, option_fmt *options);
-extern void pdf_print_results (float *page_height, world_fmt ** universe, option_fmt * options, data_fmt * data);
+extern void pdf_print_results (world_fmt ** universe, option_fmt * options, data_fmt * data);
 extern void pdf_print_profile_title(world_fmt *world);
 extern void pdf_print_profile_table(float left_margin, float * page_height, char method, char *buffer, world_fmt *world);
 extern long prepare_profile_table(char method, long which, MYREAL *likes, MYREAL **param, world_fmt *world, long bufsize);
@@ -129,4 +128,18 @@ extern int pdf_write_file(option_fmt *options);
 #ifndef HAVE_STRSEP
 char *strsep(char **, const char *);
 #endif
+
+extern  pdf_doc doc;
+extern  pdf_page page;
+extern  pdf_contents canvas;
+extern  int page_counter;
+extern  char pdf_pagetitle[LINESIZE+1];
+extern  char pdf_time[LINESIZE+1];
+extern  float page_height;
+extern  float left_margin;
+extern int numcpu;
+extern pdf_contents firstcanvas;
+extern  float timestampy;
+
+
 #endif
