@@ -51,32 +51,191 @@ extern int myID;
 MYREAL cdf_gamma(MYREAL a, MYREAL b, MYREAL x);
 MYREAL trunc_gamma_rand(MYREAL alpha, MYREAL beta, MYREAL lower, MYREAL upper);
 MYREAL normal_rand(MYREAL mean, MYREAL std);
+
+MYREAL propose_uni_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r);
+MYREAL propose_exp_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r);
+MYREAL propose_expb_newparam (MYREAL param,long which, world_fmt *world, MYREAL *r);
+MYREAL propose_mult_newparam (MYREAL param,long which, world_fmt *world, MYREAL *r);
+MYREAL propose_normal_newparam (MYREAL param,long which, world_fmt *world, MYREAL *r);
+MYREAL propose_gamma_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r);
+
+MYREAL log_prior_ratio_uni  (MYREAL newparam, MYREAL oldparam, bayes_fmt *bayes, long which);
+MYREAL log_prior_ratio_exp  (MYREAL newparam, MYREAL oldparam, bayes_fmt *bayes, long which);
+MYREAL log_prior_ratio_wexp (MYREAL newparam, MYREAL oldparam, bayes_fmt *bayes, long which);
+MYREAL log_prior_ratio_mult (MYREAL newparam, MYREAL oldparam, bayes_fmt *bayes, long which);
+MYREAL log_prior_ratio_normal (MYREAL newparam, MYREAL oldparam, bayes_fmt *bayes, long which);
+MYREAL log_prior_ratio_gamma(MYREAL newparam, MYREAL oldparam, bayes_fmt * bayes, long which);
+
+
+MYREAL log_prior_uni  (world_fmt * world, long numparam);//for heating
+MYREAL log_prior_exp  (world_fmt * world, long numparam);//for heating
+MYREAL log_prior_wexp (world_fmt * world, long numparam);//for heating
+MYREAL log_prior_mult (world_fmt * world, long numparam);//for heating
+MYREAL log_prior_normal (world_fmt * world, long numparam);//for heating
+MYREAL log_prior_gamma(world_fmt *world, long numparam);
+
+MYREAL log_prior_uni1  (world_fmt * world, long numparam, MYREAL);
+MYREAL log_prior_exp1  (world_fmt * world, long numparam, MYREAL);
+MYREAL log_prior_wexp1 (world_fmt * world, long numparam, MYREAL);
+MYREAL log_prior_mult1 (world_fmt * world, long numparam, MYREAL);
+MYREAL log_prior_normal1 (world_fmt * world, long numparam, MYREAL);
+MYREAL log_prior_gamma1(world_fmt *world, long numparam, MYREAL val);
+
+
+MYREAL hastings_ratio_uni(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+MYREAL hastings_ratio_exp(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+MYREAL hastings_ratio_expb(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+MYREAL hastings_ratio_mult(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+MYREAL hastings_ratio_normal(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+MYREAL hastings_ratio_gamma(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam);
+
+void init_hyperpriorrecord(hyper_fmt ** hyperp,long numparam);
+void hyper_gamma_record(MYREAL alpha, MYREAL beta, hyper_fmt * hg);
+void hyper_report(world_fmt *world, bayes_fmt *bayes);
+MYREAL propose_uniform(MYREAL param, MYREAL minparam, MYREAL maxparam, MYREAL *r, MYREAL delta);
+void set_option_prior(prior_fmt **p, int type, MYREAL mini, MYREAL maxi, MYREAL mean, long bins);
+prior_fmt * copy_option_prior(prior_fmt *pmodel, option_fmt *options, MYREAL ratemin);
+prior_fmt * insert_prior(prior_fmt *p, prior_fmt **plist,long *z,option_fmt * options);
+prior_fmt * insert_prior_old(option_fmt *options, long index, prior_fmt *p, long type);
+void check_bayes_priors(option_fmt *options, data_fmt *data, world_fmt *world);
+prior_fmt * get_prior_list(prior_fmt **list, int type);
+MYREAL find_beta_truncgamma(MYREAL mean, MYREAL alpha, MYREAL lower, MYREAL upper);
+/*
+void setup_type_matrix(world_fmt *world)
+{
+  long typecounts = 2 + world->species_model_size * 2 + world->bayes->mu;
+  world->bayes->rules->indicesnum = (long *) mycalloc(typecounts,sizeof(long));
+  world->bayes->rules->indices = (long **) mycalloc(typecounts,sizeof(long * ));
+  long i;
+  world->bayes->rules->indices[0] = (long *) mycalloc(world->numpop,sizeof(long));
+  world->bayes->rules->indicesnum[0] = world->numpop;
+  for (i=0;i<world->numpop;i++)
+    {
+      if (world->options->custm2[i]=='*')
+	world->bayes->rules->indices[0][i] = i;
+      else
+	world->bayes->rules->indices[0][i] = -1;
+    }
+  if (world->numpop>1)
+    {
+      world->bayes->rules->indicesnum[1] = world->numpop2 - world->numpop;
+      for (i=world->numpop; i < world->numpop2;i++)
+	{
+	  if (world->options->custm2[i]=='*')
+	    world->bayes->rules->indices[1][i] = i;
+	  else
+	    world->bayes->rules->indices[1][i] = -1;
+	}
+      long start = world->numpop2+world->bayes->mu;
+      world->bayes->rules->indicesnum[3] = world->species_model_size;
+      world->bayes->rules->indicesnum[4] = world->species_model_size;
+      for (i=start;i < start + world->species_model_size*2; i+=2)
+	{
+	  world->bayes->rules->indices[3][i] = i;
+	  world->bayes->rules->indices[4][i+1] = i+1;
+	}
+    }
+  if (world->bayes->mu)
+    {
+      world->bayes->rules->indicesnum[2] = 1;
+      world->bayes->rules->indices[2][i] = world->numpop2;
+    }
+  else
+    {
+      world->bayes->rules->indicesnum[2] = 1;
+      world->bayes->rules->indices[2][i] = -1;
+    }
+}
+*/
+
+static long * which_type(long which, world_fmt * world, long *mainindex)
+{
+  if (which < world->numpop)
+    {
+      *mainindex = 0;
+      return world->bayes->rules->indices[0];
+    }
+  else if (which < world->numpop2)
+    {
+      *mainindex = 1;
+      return world->bayes->rules->indices[1];
+    }
+  else if (which == world->numpop2 && world->bayes->mu)
+    {
+      *mainindex = 2;
+      return world->bayes->rules->indices[2];
+    }
+  else if (which >= world->numpop2 && which % 2 == 0)
+    {
+      *mainindex = 3;
+      return world->bayes->rules->indices[3];
+    }
+  else
+    {
+      *mainindex = 4;
+      return world->bayes->rules->indices[4];
+    }
+}
+
+// check whether the value drawn from the prior fits into the rule set
+// specified in bayes->rules->custm2rules[i] with i=0 .. bayes->rules->rulesnum
+// currently accepts only a single rule
+static boolean rule_check(MYREAL value, long which, world_fmt *world)
+{
+  char alfabet[] = "abcdefghijklmnopqrstuvwz";
+  if (world->bayes->rules == NULL)
+    return TRUE;
+  char ** rules = world->bayes->rules->custm2rules;
+  //long numrules = world->bayes->rules->rulesnum;
+  char myrule = rules[0][which];
+  long i=0;
+  if(strchr("SsMm0c", myrule))
+    return TRUE;
+  
+  long *indices;
+  long mainindex;
+  indices = which_type(which, world,&mainindex);
+  for (i=0; i< world->bayes->rules->indicesnum[mainindex]; i++)
+    {
+      long ind = indices[i];
+      if (myrule < alfabet[ind] && value >= world->param0[ind])
+	{
+	  myfree(indices);
+	  return FALSE;
+	}
+    }
+  return TRUE;
+}
+
+
+
 ///
 /// Normal distribution
 /// this generates only one random number, but could be easily changed to supply two numbers
 MYREAL normal_rand(MYREAL mean, MYREAL std)
 {
-  MYREAL u = RANDUM();
-  MYREAL v = RANDUM();
-  return sqrt(-2 * log(u)) * cos(TWOPI*v);
+  MYREAL u = UNIF_RANDUM();
+  MYREAL v = UNIF_RANDUM();
+  return (sqrt(-2 * log(u)) * cos(TWOPI*v)) * std + mean;
   //return sqrt(-2 * log(u)) * sin(TWOPI*v);
 }
 
 // for prior_fmt
-float trunc_random_normal(float *p)
+static float trunc_random_normal(float *p)
 {
   float r = (float) normal_rand(p[2],p[3]);
   while (r < p[0] || r > p[1])
-    r = normal_rand(p[2],p[3]);
+    r = (float) normal_rand(p[2],p[3]);
   return r;
 }
 
 // for prior_fmt
-float cdf_normal(float x, float *p)
+static float cdf_normal(float x, float *p)
 {
-  return 0.5 * (1.0 + erf((x-p[2])/(sqrt(2.0) * p[3])));
+  return (float) (0.5 * (1.0 + erf((x-p[2])/(sqrt(2.0) * p[3]))));
 }
-float trunc_cdf_normal(float x, float *p)
+
+static float trunc_cdf_normal(float x, float *p)
 {
   float aa =  cdf_normal((p[0]-p[2])/p[3],p);
   float Z = cdf_normal((p[1]-p[2])/p[3],p) - aa;
@@ -84,51 +243,51 @@ float trunc_cdf_normal(float x, float *p)
 }
 
 // uniform for prior_fmt
-float trunc_random_uni(float *p)
+static float trunc_random_uni(float *p)
 {
-  MYREAL u = RANDUM();
-  return p[0] + (p[1]-p[0]) * u;
+  MYREAL u = UNIF_RANDUM();
+  return (float) (p[0] + (p[1]-p[0]) * u);
 }
 
 // uniform for prior_fmt
-float trunc_cdf_uni(float x, float *p)
+static float trunc_cdf_uni(float x, float *p)
 {
   //x==(y-p[0])/(p[1]-p[0])
   return x * (p[1] - p[0]) + p[0];
 }
 
 // uniform for prior_fmt
-float trunc_random_exp(float *p)
+static float trunc_random_exp(float *p)
 {
-  MYREAL u = RANDUM();
-  float r = -log(u) * p[2];
+  MYREAL u = UNIF_RANDUM();
+  float r = (float) (-log(u) * p[2]);
     while(r < p[0] || r > p[1])
       {
-	u = RANDUM();
-	r = -log(u) * p[2];
+	u = UNIF_RANDUM();
+	r = (float) (-log(u) * p[2]);
       }
     return r;
 }
 
 // uniform for prior_fmt
-float trunc_cdf_exp(float x, float *p)
+static float trunc_cdf_exp(float x, float *p)
 {
-  float lambda = 1.0/p[2];
+  float lambda = 1.0f/p[2];
   //float cdfx = 1.0 - exp(-lambda * x);
-  float cdfa = 1.0 - exp(-lambda * p[0]);
-  float cdfb = 1.0 - exp(-lambda * p[1]);
+  float cdfa = (float) (1.0 - exp(-lambda * p[0]));
+  float cdfb = (float) (1.0 - exp(-lambda * p[1]));
   //return cdfx/(cdfb-cdfa);
-  return -log(-x * (cdfb-cdfa) + 1.0)/lambda;
+  return (float) (-log(-x * (cdfb-cdfa) + 1.0)/lambda);
 }
 
-float trunc_random_gamma(float *p)
+static float trunc_random_gamma(float *p)
 {
   MYREAL alpha = p[2];
   MYREAL beta = p[3];
   return  (float) trunc_gamma_rand(alpha,beta,p[0],p[1]);
 }
 
-double bisection(int n, double a, double b, double tol, float p[], float x) {
+static double bisection(int n, double a, double b, double tol, float p[], float x) {
   MYREAL alpha = p[2];
   MYREAL beta = p[3];
   if (beta < SMALLEPSILON)
@@ -136,16 +295,16 @@ double bisection(int n, double a, double b, double tol, float p[], float x) {
       beta = SMALLEPSILON;
     }
   MYREAL Z = cdf_gamma(alpha, beta, p[1]) -cdf_gamma(alpha, beta, p[0]);
-  float fa = (float) cdf_gamma(alpha, beta, a)/Z - x;
+  float fa = (float) (cdf_gamma(alpha, beta, a)/Z - x);
   //float fb = (float) cdf_gamma(alpha, beta, b)/Z - x;
-  float     c = (a + b) / 2.0;
+  double     c = (a + b) / 2.0;
   float fc;
   int count = 0;
   
   while (((b - a) > tol) && (count++ < n)) 
     {
       c = (a + b) / 2.0;
-      fc = (float) cdf_gamma(alpha, beta, c)/Z - x;
+      fc = (float) (cdf_gamma(alpha, beta, c)/Z - x);
       if (fc < 0.0) 
 	{
 	  if (fa < 0.0) 
@@ -177,79 +336,13 @@ double bisection(int n, double a, double b, double tol, float p[], float x) {
 }
 
 
-float trunc_cdf_gamma(float x, float *p)
+static float trunc_cdf_gamma(float x, float *p)
 {
-  return  bisection(100, p[0],p[1], 0.0001, p, x); 
+  return  (float) (bisection(100, p[0],p[1], 0.0001, p, x)); 
 }
 
-///
-// Gamma distribution
-//
-// gamma deviated random number 
-// from Marsaglia G., Tsang, W. W. (2000) A simple method for generating Gamma variables. 
-// ACM Transactions on Mathematical Software Vol 26. No. 3: 363-372
-// requirements are a 
-//   - normal random number generator
-//   - uniform random number generator
-//
-// [see Python program to test implementation] 
-//
-// returns a random number for shape parameter alpha>=1 and scale parameter beta=1
-MYREAL __gamma_rand(MYREAL alpha)
-{
-  const MYREAL d = alpha - 1./3.;
-  const MYREAL c = 1./sqrt(9. * d);
-  MYREAL v,x,xx, u;
-  while(1)
-    {
-      x = normal_rand(0.,1.);
-      v = 1. + c * x;
-      while(v<=0.0)
-	{
-	  x = normal_rand(0.,1.);
-	  v = 1. + c * x;
-	}
-      v  = v * v * v;
-      u  = RANDUM();
-      xx = x * x;
-      if (u < 1.0-0.0331*xx*xx)
-	return d*v;
-      if (log(u) < 0.5*xx + d * (1.0 - v + log(v)))
-	return d*v;
-    }
-}
 
-/// returns a random number from a gamma distribution with shape parameter alpha and scale parameter beta
-MYREAL gamma_rand(MYREAL alpha, MYREAL beta)
-{
-  MYREAL aa;
-  if (alpha<1.0)
-    {
-      aa = 1.0 + alpha;
-      return __gamma_rand(aa)*pow(RANDUM(),(1.0/alpha)) * beta;
-    }
-  else
-    {
-      return __gamma_rand(alpha) * beta;
-    }
-}
-
-/// returns a random number from a truncated gamma distribution
-MYREAL trunc_gamma_rand(MYREAL alpha, MYREAL beta, MYREAL lower, MYREAL upper)
-{
-  MYREAL x;
-  while(1)
-    {
-      x = gamma_rand(alpha,beta);
-      if (lower < x)
-	{
-	  if (x < upper)
-	    return x;
-	}
-    }
-}
-
-MYREAL logpdf_gamma(MYREAL a, MYREAL b, MYREAL x)
+static MYREAL logpdf_gamma(MYREAL a, MYREAL b, MYREAL x)
 {
   if (a>0.0 && b> 0.0)
     return -(x/b) - a*log(b) + (-1 + a)*log(x) - LGAMMA(a);
@@ -263,7 +356,7 @@ MYREAL cdf_gamma(MYREAL a, MYREAL b, MYREAL x)
   return incompletegamma(x/b,a);
 }
 
-MYREAL logpdf_truncgamma(MYREAL a, MYREAL b, MYREAL  xmin, MYREAL xmax, MYREAL x)
+static MYREAL logpdf_truncgamma(MYREAL a, MYREAL b, MYREAL  xmin, MYREAL xmax, MYREAL x)
 {
   if((x > xmin) && (x <= xmax))
     return logpdf_gamma(a,b,x)-log(cdf_gamma(a,b,xmax)-cdf_gamma(a,b,xmin));
@@ -272,7 +365,7 @@ MYREAL logpdf_truncgamma(MYREAL a, MYREAL b, MYREAL  xmin, MYREAL xmax, MYREAL x
 }
 
 
-MYREAL mean_truncgamma(MYREAL alpha, MYREAL beta, MYREAL lower, MYREAL upper)
+static MYREAL mean_truncgamma(MYREAL alpha, MYREAL beta, MYREAL lower, MYREAL upper)
 {
   MYREAL n1, n2, d1, d2;
   MYREAL m;
@@ -329,36 +422,37 @@ MYREAL find_beta_truncgamma(MYREAL mean, MYREAL alpha, MYREAL lower, MYREAL uppe
   while (n<= nmax)
     {
       beta = (a+b)/2.0;
-      fbeta = mean_truncgamma(alpha,beta,lower,upper) - mean;    
+      fbeta = mean_truncgamma(alpha,beta,0.0,HUGE) - mean; // see fa   
       if(fbeta  == 0.0 || (b-a)/2. < tolerance)
 	{
 	  //printf("beta=%f\n",beta);
 	  return beta;
 	}
       n += 1;
-      fa = mean_truncgamma(alpha,a,lower,upper) - mean;    
-      if(((fbeta<0.0) && (fa<0.0)) || ((fbeta>0.0) && (fa>0.0)))
-	a = beta;
-      else
+      fa = mean_truncgamma(alpha,a,0.0,HUGE) - mean; //lower,upper replaced 
+      // with 0 and large value to allow better mean recovery with tight lower,upper bounds    
+      if(((fbeta > 0.0) && (fa < 0.0)) || ((fbeta<0.0) && (fa>0.0)))
 	b = beta;
+      else
+	a = beta;
     }
   warning("limit reached without achieving necessary accuracy");
   //printf("beta=%f --------------\n",beta);
   return beta;
 }
 	
-void init_hyperpriorrecord(hyper_fmt ** hyper,long numparam)
+void init_hyperpriorrecord(hyper_fmt ** hyperp,long numparam)
 {
   long i;
-  (*hyper) = (hyper_fmt *) calloc(numparam, sizeof(hyper_fmt));
+  (*hyperp) = (hyper_fmt *) mycalloc(numparam, sizeof(hyper_fmt));
   for(i=0;i<numparam;i++)
     {
-      onepass_mean_std_start(&(*hyper)[i].alpha, &(*hyper)[i].alphastd, &(*hyper)[i].alphan);
-      onepass_mean_std_start(&(*hyper)[i].mean, &(*hyper)[i].meanstd, &(*hyper)[i].meann);
+      onepass_mean_std_start(&(*hyperp)[i].alpha, &(*hyperp)[i].alphastd, &(*hyperp)[i].alphan);
+      onepass_mean_std_start(&(*hyperp)[i].mean, &(*hyperp)[i].meanstd, &(*hyperp)[i].meann);
     }
 }
 
-void hyper_normal(MYREAL *mean, MYREAL *std, MYREAL origmean, MYREAL origstd, MYREAL lower, MYREAL upper, MYREAL factor)
+static void hyper_normal(MYREAL *mean, MYREAL *std, MYREAL origmean, MYREAL origstd, MYREAL lower, MYREAL upper, MYREAL factor)
 {
   // use a normal to draw new means, alpha, and then recalculate beta
   // using the original prior mean as the mean and std of the normal
@@ -375,7 +469,8 @@ void hyper_normal(MYREAL *mean, MYREAL *std, MYREAL origmean, MYREAL origstd, MY
   *mean = nmean;
   *std = nstd;
 }
-void hyper_gamma(MYREAL *alpha, MYREAL *beta, MYREAL origmean, MYREAL origalpha, MYREAL lower, MYREAL upper, MYREAL factormean, MYREAL factoralpha)
+
+static void hyper_gamma(MYREAL *alpha, MYREAL *beta, MYREAL origmean, MYREAL origalpha, MYREAL lower, MYREAL upper, MYREAL factormean, MYREAL factoralpha)
 {
   // use a normal to draw new means, alpha, and then recalculate beta
   // using the original prior mean as the mean and std of the normal
@@ -408,7 +503,7 @@ void hyper_gamma_record(MYREAL alpha, MYREAL beta, hyper_fmt * hg)
 
 void hyper_report(world_fmt *world, bayes_fmt *bayes)
 {
-  hyper_fmt *hyper = bayes->hyper;
+  hyper_fmt *hyperp = bayes->hyperp;
   long i;
   fprintf(world->outfile, "Hyperpriors are active\n");
   fprintf(world->outfile, "----------------------\n");
@@ -418,19 +513,21 @@ void hyper_report(world_fmt *world, bayes_fmt *bayes)
   for (i=0;i<bayes->numparams;i++)
     {
       fprintf(world->outfile,"%li        %f  %f  %f %f %li\n", 
-	      i+1, hyper->mean, hyper->meanstd, 
-	      hyper->alpha, hyper->alphastd, 
-	      hyper->alphan);
+	      i+1, hyperp->mean, hyperp->meanstd, 
+	      hyperp->alpha, hyperp->alphastd, 
+	      hyperp->alphan);
     }
 }
 
 ///
 /// Gamma prior retrieve a new value from a truncated gamma between lower and upper
 /// currently does not use the old parameter, but this 
-MYREAL
-propose_gamma_newparam (MYREAL param, long which, bayes_fmt * bayes, MYREAL *r)
+MYREAL propose_gamma_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r)
 {
+  (void) param;
+  (void) r;
   MYREAL rr;
+  bayes_fmt *bayes = world->bayes;
   // test with delta
   // const MYREAL delta = bayes->delta[which];
   // const MYREAL l = param - delta;
@@ -441,16 +538,18 @@ propose_gamma_newparam (MYREAL param, long which, bayes_fmt * bayes, MYREAL *r)
   const MYREAL upper = bayes->maxparam[which]; 
   MYREAL alpha = bayes->alphaparam[which];
   MYREAL beta = bayes->betaparam[which];
-  if (bayes->hyperprior && bayes->hyper[which].count++ % bayes->hyperinterval == 0)
+  if (bayes->hyperprior && bayes->hyperp[which].count++ % bayes->hyperinterval == 0)
     {
       const MYREAL mean = bayes->meanparam[which];
       hyper_gamma(&alpha, &beta, mean, bayes->alphaorigparam[which], lower, upper,bayes->hyperfactormean,bayes->hyperfactoralpha);
       bayes->alphaparam[which] = alpha;
       bayes->betaparam[which] = beta;
-      hyper_gamma_record(alpha,beta, &bayes->hyper[which]);
+      hyper_gamma_record(alpha,beta, &bayes->hyperp[which]);
     }
   //rr = trunc_gamma_rand(alpha, beta, param-delta, param+delta);
   rr = trunc_gamma_rand(alpha, beta, lower, upper);
+  while (!rule_check(rr,which, world))
+      rr = trunc_gamma_rand(alpha, beta, lower, upper);
   return rr;
 }
 
@@ -463,6 +562,9 @@ propose_gamma_newparam (MYREAL param, long which, bayes_fmt * bayes, MYREAL *r)
 /// cancels with log_prior_gamma -> 0.0
 MYREAL hastings_ratio_gamma(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
 {
+  (void) oldparam;
+  (void) delta;
+  (void) r;
   if((newparam > bayes->maxparam[whichparam]) || (newparam < bayes->minparam[whichparam]))
     return -HUGE;
   else
@@ -473,11 +575,9 @@ MYREAL hastings_ratio_gamma(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYRE
 ///
 /// Log Prior gamma distribution ratios between old and new parameter:
 /// cancels with hastings ratio
-MYREAL log_prior_ratio_gamma(MYREAL newparam, 
-			   MYREAL oldparam, 
-			   bayes_fmt * bayes, 
-			   long which)
+MYREAL log_prior_ratio_gamma(MYREAL newparam, MYREAL oldparam, bayes_fmt * bayes, long which)
 {
+  (void) oldparam;
   if((newparam > bayes->maxparam[which]) || (newparam < bayes->minparam[which]))
     return -HUGE;
   else
@@ -543,7 +643,268 @@ MYREAL log_prior_gamma1(world_fmt *world, long numparam, MYREAL val)
   return retval;
 }
 
+///////////////////////////////////////////////////////////////////////
+// uniform prior
+///
+/// Uniform flat prior, coding based on Rasmus Nielsen, veryfied with mathematica
+/// the correlation among values is dependent on delta
+MYREAL propose_uniform(MYREAL param, MYREAL minparam, MYREAL maxparam, MYREAL *r, MYREAL delta)
+{
+  MYREAL thisdelta;
+  MYREAL rr;
+  MYREAL np=0.0;
+  *r = UNIF_RANDUM();
+  rr = (*r) - 0.5;
+  thisdelta = rr * delta;
+  np = param + thisdelta;
+  if (np > maxparam)
+    {
+      np =  2. * maxparam - np;
+    }
+  else
+    {
+      if (np < minparam)
+	{
+	  np = 2. * minparam - np;
+	}
+    }
+  return np;
+}
 
+MYREAL
+propose_uni_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r)
+{
+  bayes_fmt *bayes = world->bayes;
+  MYREAL minparam = bayes->minparam[which];
+  MYREAL delta = bayes->delta[which];
+  MYREAL maxparam = bayes->maxparam[which];
+  MYREAL np = propose_uniform(param, minparam, maxparam, r, delta);
+  while (!rule_check(np,which, world))
+    {
+      np = propose_uniform(param, minparam, maxparam, r, delta);
+    }
+  return np;
+}
+
+
+
+///
+/// Hastings ratio calculator for uniform distribution
+MYREAL hastings_ratio_uni(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
+{
+  (void) newparam;
+  (void) oldparam;
+  (void) delta;
+  (void) r;
+  (void) bayes;
+  (void) whichparam;
+
+    //  return  (newparam - oldparam)/bayes->priormean[whichparam];
+    return 0.;
+}
+
+
+///////////////////////////////////////////////////////////////////////
+// exponential prior
+/// \brief Exponential prior distribution
+/// exponential prior distribution using the gamma prior with alpha=1
+///
+MYREAL
+propose_exp_newparam (MYREAL param, long which, world_fmt *world,  MYREAL * r)
+{
+  MYREAL rr = propose_gamma_newparam (param, which, world, r);
+  while (!rule_check(rr,which, world))
+    {
+      *r = UNIF_RANDUM();
+      rr = propose_gamma_newparam (param, which, world, r);
+    }
+  return rr;
+}
+
+///
+/// Hastings ratio calculator for exponential distribution
+MYREAL hastings_ratio_exp(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
+{
+  (void) newparam;
+  (void) oldparam;
+  (void) delta;
+  (void) r;
+  (void) bayes;
+  (void) whichparam;
+    return 0.;
+}
+
+
+///
+/// uses an exponential prior with boundaries minparm and maxparm and uses also a window around the old parameter
+/// the window is of arbitrary size
+/// (see propose_exp_newparam() for details)
+MYREAL
+propose_expb_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r)
+{
+  MYREAL rr = propose_gamma_newparam (param, which, world, r);
+  while (!rule_check(rr,which, world))
+    {
+      *r = UNIF_RANDUM();
+      rr = propose_gamma_newparam (param, which, world, r);
+    }
+  return rr;
+}
+
+///
+/// Hastings ratio calculator for exponential distribution
+MYREAL hastings_ratio_expb(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
+{
+  (void) newparam;
+  (void) oldparam;
+  (void) delta;
+  (void) r;
+  (void) bayes;
+  (void) whichparam;
+
+    return 0. ;
+}
+
+///////////////////////////////////////////////////////////////////////
+// Multiplier prior (not working?)
+///
+/// Multiplier move, the parameter is multiplied with the rate 1/(lambda*m)
+///
+/// Requirements:
+///     a < m < b
+///     a = 1/b
+///
+///
+MYREAL
+propose_mult_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r)
+{
+    const MYREAL delta = world->bayes->delta[which];
+    const MYREAL maxparam = world->bayes->maxparam[which];
+    MYREAL multiplier;  // minmult < multiplier < maxmult
+    MYREAL maxmult = delta;
+    //MYREAL minmult = 1/maxmult;
+    MYREAL lambda = 2. * log(maxmult); // tuning parameter \lambda = 2 ln(b)
+    MYREAL np ;
+    multiplier = EXP(lambda * ((*r) - 0.5));	
+    np = multiplier * param;
+    (*r) = multiplier;
+    
+    while(np > maxparam)
+      {
+	np = maxparam * maxparam / np;
+      }
+    while (!rule_check(np,which, world))
+      {
+	*r = UNIF_RANDUM();
+	multiplier = EXP(lambda * ((*r) - 0.5));	
+	np = multiplier * param;
+	(*r) = multiplier;
+	
+	while(np > maxparam)
+	  {
+	    np = maxparam * maxparam / np;
+	  }
+      }
+    return np;
+}
+
+///
+/// Hastings ratio calculator for exponential distribution with multiplicator
+/// using the old parameter as mean value
+/// simply the jacobian from x->param, matrix if derivatives [should be seocnd right?]
+/// [check this with the green paper]
+/// first derivatives
+MYREAL hastings_ratio_mult(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
+{
+    // q(x|x')     1/(lambda(1/m))    | dx'/dx       dx'/du  |
+    // ------------      -----------------------------    |                      |   =
+    // q(x'|x)     1/(lambda m)       | du'/dx       du'/du  |
+    //
+    //          |  dmx/dx       dmx/dm     |
+    // = m^2    |                          | = m^2  |(m (-1/m^2) - x zero| = m^2 m/m^2 = m
+    //          |  d(1/m)/dx    d(1/m)/dm  |
+  (void) newparam;
+  (void) oldparam;
+  (void) delta;
+  (void) bayes;
+  (void) whichparam;
+  return log(r); // rate multiplier
+}
+
+
+///////////////////////////////////////////////////////////////////////
+// ratio normal prior
+
+MYREAL log_prior_ratio_normal(MYREAL newparam,
+                              MYREAL oldparam,
+                              bayes_fmt * bayes,
+                              long which)
+{
+  (void) oldparam;
+    if((newparam > bayes->maxparam[which]) || (newparam < bayes->minparam[which]))
+        return -HUGE;
+    else
+        return 0.0 ;
+}
+
+MYREAL log_prior_normal(world_fmt *world, long numparam)
+{
+    MYREAL val = world->param0[numparam];
+    return log_prior_normal1(world,numparam,val);
+}
+///
+/// normal prior distribution, returns 1/(sqrt(Pi*1) exp(-(x-mu)^2/2)
+MYREAL log_prior_normal1(world_fmt *world, long numparam, MYREAL val)
+{
+    bayes_fmt * bayes = world->bayes;
+    long i = numparam;
+    MYREAL retval = -HUGE;
+    MYREAL p0 = val;
+    MYREAL mean = bayes->meanparam[i];
+    MYREAL x;
+    if((p0 <= bayes->maxparam[i]) && (p0 >= bayes->minparam[i]))
+    {
+        x = p0 - mean;
+        retval = LOG2PIHALF - x*x/2.0;
+        // bayes->maxparam[i] - bayes->minparam[i];
+        if (retval > 0.0)
+            return retval;
+    }
+    return retval;
+}
+
+MYREAL hastings_ratio_normal(MYREAL newparam, MYREAL oldparam, MYREAL delta, MYREAL r, bayes_fmt * bayes, long whichparam)
+{
+  (void) newparam;
+  (void) oldparam;
+  (void) delta;
+  (void) r;
+  (void) bayes;
+  (void) whichparam;
+    return 0.;
+}
+
+MYREAL
+propose_normal_newparam (MYREAL param, long which, world_fmt *world, MYREAL *r)
+{
+  (void) param;
+  bayes_fmt * bayes = world->bayes;
+    MYREAL rr = (*r) - 0.5;
+    MYREAL lower = bayes->minparam[which];
+    //MYREAL meanparam = bayes->meanparam[which];
+    MYREAL upper = bayes->maxparam[which];
+    MYREAL std = 1.0;
+    MYREAL mean = bayes->meanparam[which];
+    if (bayes->hyperprior && bayes->hypercount++ % bayes->hyperinterval == 0)
+    {
+      hyper_normal(&mean, &std, mean, 1.0, lower, upper, 1.0);
+    }
+    rr = normal_rand(mean,std);
+    return rr;
+}
+
+
+///////////////////////////////////////////////////////////////////////
 
 void set_option_prior(prior_fmt **p, int type, MYREAL mini, MYREAL maxi, MYREAL mean, long bins)
 {
@@ -566,7 +927,7 @@ void set_option_prior(prior_fmt **p, int type, MYREAL mini, MYREAL maxi, MYREAL
       strcpy((*p)->ptypename,"RATE"); break;
     default:
       error("unknown prior in check_bayes_priors()");
-	break;
+      //break;
     }
   (*p)->delta = (maxi-mini)/b;
   (*p)->min = mini;
@@ -580,6 +941,7 @@ void set_option_prior(prior_fmt **p, int type, MYREAL mini, MYREAL maxi, MYREAL
 
 prior_fmt * copy_option_prior(prior_fmt *pmodel, option_fmt *options, MYREAL ratemin)
 {
+  (void) options;
   prior_fmt * p = (prior_fmt *) calloc(1,sizeof(prior_fmt));
   p->next = NULL;
   p->kind = pmodel->kind;
@@ -621,6 +983,7 @@ prior_fmt * insert_prior(prior_fmt *p, prior_fmt **plist,long *z,option_fmt * op
 
 prior_fmt * insert_prior_old(option_fmt *options, long index, prior_fmt *p, long type)
 {
+  (void) index;
   prior_fmt *q, *tmp;
   if (p==NULL)
     return NULL;
@@ -636,7 +999,7 @@ prior_fmt * insert_prior_old(option_fmt *options, long index, prior_fmt *p, long
     return p->next;
   return p;
 }
-
+/*
 long count_d(char *s)
 {
   long count=0;
@@ -649,10 +1012,12 @@ long count_d(char *s)
     }
   return count;
 }
+*/
 
 /// checks the settings of the number of long an short chain for bayes options and resets useless settings
 void check_bayes_priors(option_fmt *options, data_fmt *data, world_fmt *world)
 {
+  (void) data;
   const long numpop = world->numpop;
   const long numpop2 = numpop * numpop;
   const int  has_mu = (int) options->bayesmurates;
@@ -667,8 +1032,8 @@ void check_bayes_priors(option_fmt *options, data_fmt *data, world_fmt *world)
   long oldnp;
   // puts the original PRIOR_SIZE priorlist aside, this gets freed at the end of this function
   options->bayes_priors_num =   options->bayes_priors_num < PRIOR_SIZE ? PRIOR_SIZE : options->bayes_priors_num;
-  prior_fmt  **plist = (prior_fmt **) calloc(options->bayes_priors_num+1, sizeof(prior_fmt *));
-  typelist = (longpair *) calloc(np,sizeof(longpair));
+  prior_fmt  **plist = (prior_fmt **) mycalloc((options->bayes_priors_num+1), sizeof(prior_fmt *));
+  typelist = (longpair *) mycalloc((size_t) np,sizeof(longpair));
   plist[0] = options->bayes_priors[0];
   prior_fmt *p = options->bayes_priors[0];
   for (i=1; i < options->bayes_priors_num; i++)
@@ -679,7 +1044,7 @@ void check_bayes_priors(option_fmt *options, data_fmt *data, world_fmt *world)
     }
   oldnp = options->bayes_priors_num;
   // resets the key priorlist to be filled with copies of elements from plist
-  options->bayes_priors = (prior_fmt **) calloc(np,sizeof(prior_fmt *));
+  options->bayes_priors = (prior_fmt **) mycalloc((size_t) np,sizeof(prior_fmt *));
   // list of types
   for(j=0;j<np;j++)
     {
@@ -766,39 +1131,39 @@ void check_bayes_priors(option_fmt *options, data_fmt *data, world_fmt *world)
   options->bayes_priors_num = np;
   for(j=0;j<np;j++)
     {
-      options->bayes_priors[j]->v[0]= options->bayes_priors[j]->min;
-      options->bayes_priors[j]->v[1]= options->bayes_priors[j]->max;
+      options->bayes_priors[j]->v[0]= (float) options->bayes_priors[j]->min;
+      options->bayes_priors[j]->v[1]= (float) options->bayes_priors[j]->max;
       switch(options->bayes_priors[j]->kind)
 	{
 	case EXPPRIOR:
 	case WEXPPRIOR:
-	  options->bayes_priors[j]->v[2]= options->bayes_priors[j]->mean;
-	  options->bayes_priors[j]->v[3]= options->bayes_priors[j]->std;
+	  options->bayes_priors[j]->v[2]= (float) options->bayes_priors[j]->mean;
+	  options->bayes_priors[j]->v[3]= (float) options->bayes_priors[j]->std;
 	  options->bayes_priors[j]->random = trunc_random_exp; 
 	  options->bayes_priors[j]->cdf = trunc_cdf_exp;
 	  break;
 	case GAMMAPRIOR:
-	  options->bayes_priors[j]->v[2]= options->bayes_priors[j]->alpha;
+	  options->bayes_priors[j]->v[2]= (float) options->bayes_priors[j]->alpha;
 	  if (options->bayes_priors[j]->beta < SMALLEPSILON)
 	    {
-	      beta = find_beta_truncgamma(options->bayes_priors[j]->mean, options->bayes_priors[j]->alpha, 
-				   options->bayes_priors[j]->min, options->bayes_priors[j]->max);
+	      beta = (float) (find_beta_truncgamma(options->bayes_priors[j]->mean, options->bayes_priors[j]->alpha, 
+						   options->bayes_priors[j]->min, options->bayes_priors[j]->max));
 	      options->bayes_priors[j]->beta = beta;
 	    }
-	  options->bayes_priors[j]->v[3]= options->bayes_priors[j]->beta;
+	  options->bayes_priors[j]->v[3]= (float) options->bayes_priors[j]->beta;
 	  options->bayes_priors[j]->random = trunc_random_gamma; 
 	  options->bayes_priors[j]->cdf = trunc_cdf_gamma;
 	  break;
 	case NORMALPRIOR:
-	  options->bayes_priors[j]->v[2]= options->bayes_priors[j]->mean;
-	  options->bayes_priors[j]->v[3]= options->bayes_priors[j]->std;
+	  options->bayes_priors[j]->v[2]= (float) options->bayes_priors[j]->mean;
+	  options->bayes_priors[j]->v[3]= (float) options->bayes_priors[j]->std;
 	  options->bayes_priors[j]->random = trunc_random_normal; 
 	  options->bayes_priors[j]->cdf = trunc_cdf_normal;
 	  break;
 	case UNIFORMPRIOR:
 	default:
-	  options->bayes_priors[j]->v[2]= options->bayes_priors[j]->mean;
-	  options->bayes_priors[j]->v[3]= options->bayes_priors[j]->std;
+	  options->bayes_priors[j]->v[2]= (float) options->bayes_priors[j]->mean;
+	  options->bayes_priors[j]->v[3]= (float) options->bayes_priors[j]->std;
 	  options->bayes_priors[j]->random = trunc_random_uni; 
 	  options->bayes_priors[j]->cdf = trunc_cdf_uni;
 	  break;
