@@ -46,6 +46,7 @@ $Id: random.c 2169 2013-08-24 19:02:04Z beerli $
 #include "heating.h"
 #include "random.h"
 #include "tools.h"
+#include "priors.h"
 #include "migrate_mpi.h"
 #ifdef WIN32
 #include <sys/timeb.h>
@@ -67,7 +68,7 @@ $Id: random.c 2169 2013-08-24 19:02:04Z beerli $
 #ifdef GRANDCENTRAL
 #include <dispatch/dispatch.h>
 #include <dispatch/semaphore.h>
-//extern dispatch_semaphore_t semaphore;
+extern dispatch_semaphore_t semaphore;
 #endif
 
 
@@ -82,6 +83,14 @@ extern sfmt_t ** sfmtH;
 /* prototypes ----------------------------------------- */
 void getseed (option_fmt * options);
 void swap_ptr (long **ptr, long **newptr);
+unsigned long int random_seed(void);
+void set_seed(long autoseed, unsigned long * inseed);
+void init_lcg(option_fmt *options);
+void getseed_lcg (option_fmt *options);
+void getseed_mt (option_fmt *options);
+void getseed_quasi (option_fmt *options);
+MYREAL failed_random_gamma(MYREAL a);
+MYREAL __gamma_rand(MYREAL alpha);
 
 MYREAL randum (void);
 #ifdef PTHREADS
@@ -422,12 +431,14 @@ MYINLINE MYREAL get_quasi()
 
 #endif
 
+/*
 #ifdef MERSENNE_TWISTER
 void setup_mersennetwister()
 {
   strncpy(generator,"Pseudo-random number generator: Mersenne twister", 79);
 }
 #endif
+*/
 
 /// random integer
 //=============================================
@@ -461,26 +472,26 @@ MYINLINE long random_integer(long low, long high)
 unsigned long int random_seed()
 {
   
-  unsigned int seed;
+  unsigned int myseed;
   struct timeval tv;
   FILE *devrandom;
   //size_t retval;
   if ((devrandom = fopen("/dev/urandom","r")) == NULL) 
     {
       gettimeofday(&tv,0);
-      seed = tv.tv_sec + tv.tv_usec;
+      myseed = (unsigned int) (tv.tv_sec + tv.tv_usec);
     }
   else 
     {
-      fread(&seed,sizeof(seed),1,devrandom);
+      fread(&myseed,sizeof(myseed),1,devrandom);
       fclose(devrandom);
-      if(seed == 0)
+      if(myseed == 0)
 	{
 	  gettimeofday(&tv,0);
-	  seed = tv.tv_sec + tv.tv_usec;
+	  myseed = (unsigned int) (tv.tv_sec + tv.tv_usec);
 	}
     }
-  return(seed);
+  return(myseed);
 }
 
 void set_seed(long autoseed, unsigned long * inseed)
@@ -510,10 +521,10 @@ void set_seed(long autoseed, unsigned long * inseed)
         break;
     default:
         error ("Error: Seed value not defined");
-        break;
+        //break;
     }
 #ifdef GRANDCENTRAL
-   //   semaphore = dispatch_semaphore_create(1);
+   semaphore = dispatch_semaphore_create(1);
 #endif
 }
 
@@ -557,7 +568,7 @@ void getseed_mt (option_fmt *options)
   strncpy(generator,"Pseudo-random number generator: Mersenne-Twister", 79);
   set_seed(options->autoseed, &options->inseed);
   options->saveseed = options->inseed;
-  sfmt_init_gen_rand(&sfmt, (unsigned long)options->inseed);
+  sfmt_init_gen_rand(&sfmt, (unsigned int) options->inseed);
   sfmtp = &sfmt;
   // multiple heated chains will use mutltiple mersenne twister streams
   // remedy for weird crashes in GCD on macs after long runs
@@ -567,12 +578,12 @@ void getseed_mt (option_fmt *options)
   // changes because the variable sfmt changed to a pointer sfmtp.
   if (options->heated_chains>1)
     {
-      sfmtH = (sfmt_t **) malloc(options->heated_chains * sizeof(sfmt_t*));
+      sfmtH = (sfmt_t **) mymalloc((size_t) options->heated_chains * sizeof(sfmt_t*));
       for (i=0;i<options->heated_chains;i++)
 	{
 	  sfmtH[i] = (sfmt_t*) malloc(sizeof(sfmt_t));
-	  long newseed = RANDINT(0,MAXLONG-1);
-	  sfmt_init_gen_rand(sfmtH[i], (unsigned long) newseed);
+	  long mynewseed = RANDINT(0,MAXLONG-1);
+	  sfmt_init_gen_rand(sfmtH[i], (unsigned int) mynewseed);
 	}
     }
   if(options->randomsubset>0 && options->randomsubsetseed > 0)
@@ -589,6 +600,7 @@ void getseed_mt (option_fmt *options)
 /// this function is dependent on running the standard MT or LCG random number generator first.
 void getseed_quasi (option_fmt *options)
 {
+  (void) options;
 #ifdef CUD
   setup_cud((int) RANDINT (1, MAXLONG-1));
 #endif
@@ -798,9 +810,9 @@ randum (void)
 #else
 #ifdef GRANDCENTRAL 
     // Wait for a free file descriptor
-    //dispatch_semaphore_wait(semaphore, DISPATCH_TIME_FOREVER);
+    dispatch_semaphore_wait(semaphore, DISPATCH_TIME_FOREVER);
     MYREAL r = sfmt_genrand_res53(sfmtp);
-    //dispatch_semaphore_signal(semaphore);
+    dispatch_semaphore_signal(semaphore);
     return r;
 #else
     MYREAL r = sfmt_genrand_res53(sfmtp);
@@ -827,6 +839,8 @@ return value;
 #endif /*phtreads*/
 
 
+///////////// this seems to fail, but unclear why ///////////////////////
+/// replaced with Marsaglia and Tsang 2000, that seems to work         //
 // Hisashi Tanizaki 2008 Economics bulletin vol 3 no 7 pp 1-10
 // A simple gamma random number generatior for arbitrary shape parameters
 //(i) Given alpha, set n, b1, b2, c1 and c2 as follows:
@@ -849,7 +863,7 @@ return value;
 //
 // to get gamma(alpha,beta) distributed values use random_gamma(alpha)*beta
 //
-MYREAL random_gamma(MYREAL a) 
+MYREAL failed_random_gamma(MYREAL a) 
 {
   const MYREAL inva = 1./ a;
   const MYREAL n = ((4.0 < a) ? sqrt(a) : ((0.4 < a) ? inva + inva *(a-0.4)/3.6 : inva)); 
@@ -881,11 +895,78 @@ MYREAL random_gamma(MYREAL a)
   return exp(x);
 }
 
+///
+// Gamma distribution
+//
+// gamma deviated random number 
+// from Marsaglia G., Tsang, W. W. (2000) A simple method for generating Gamma variables. 
+// ACM Transactions on Mathematical Software Vol 26. No. 3: 363-372
+// requirements are a 
+//   - normal random number generator
+//   - uniform random number generator
+//
+// [see Python program to test implementation] 
+//
+// returns a random number for shape parameter alpha>=1 and scale parameter beta=1
+MYREAL __gamma_rand(MYREAL alpha)
+{
+  const MYREAL d = alpha - 1./3.;
+  const MYREAL c = 1./sqrt(9. * d);
+  MYREAL v,x,xx, u;
+  while(1)
+    {
+      x = normal_rand(0.,1.);
+      v = 1. + c * x;
+      while(v<=0.0)
+	{
+	  x = normal_rand(0.,1.);
+	  v = 1. + c * x;
+	}
+      v  = v * v * v;
+      u  = UNIF_RANDUM();
+      xx = x * x;
+      if (u < 1.0-0.0331*xx*xx)
+	return d*v;
+      if (log(u) < 0.5*xx + d * (1.0 - v + log(v)))
+	return d*v;
+    }
+}
+
+/// returns a random number from a gamma distribution with shape parameter alpha and scale parameter beta
+MYREAL gamma_rand(MYREAL alpha, MYREAL beta)
+{
+  MYREAL aa;
+  if (alpha<1.0)
+    {
+      aa = 1.0 + alpha;
+      return __gamma_rand(aa)*pow(UNIF_RANDUM(),(1.0/alpha)) * beta;
+    }
+  else
+    {
+      return __gamma_rand(alpha) * beta;
+    }
+}
+
+/// returns a random number from a truncated gamma distribution
+MYREAL trunc_gamma_rand(MYREAL alpha, MYREAL beta, MYREAL lower, MYREAL upper)
+{
+  MYREAL x;
+  while(1)
+    {
+      x = gamma_rand(alpha,beta);
+      if (lower < x)
+	{
+	  if (x < upper)
+	    return x;
+	}
+    }
+}
+
 MYREAL random_beta(MYREAL a, MYREAL b)
 {
   MYREAL x,y; 
-  x = random_gamma(a); 
-  y = random_gamma(b); 
+  x = gamma_rand(a,1.0); 
+  y = gamma_rand(b,1.0); 
   return x/(x+y);
 }
 
