@@ -74,14 +74,30 @@ void calc_allgelmanb (MYREAL *gelmanb, MYREAL *mc, MYREAL *chainmeans, long *nme
 void calc_allgelmanw2 (MYREAL *gelmanw, MYREAL *chain_s, long *nmeans, long len, long maxreplicate);
 void calc_allgelmanr (MYREAL *gelmanr, MYREAL *gelmanw, MYREAL *gelmanb, long *nmeans, long len, long maxreplicate);
 
+void collect_acceptance(world_fmt *world);
+void collect_ess_values(world_fmt *world);
+void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset, 
+		     MYREAL *autocorr, MYREAL *effsample);
+MYREAL single_chain_var(world_fmt *world, unsigned long T, MYREAL *variance, MYREAL *autoc, MYREAL *effsample);
+void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locus, MYREAL *autoc, MYREAL *effsample);
+boolean max_ess(const MYREAL * ess, long n, const MYREAL minimum, MYREAL *miness);
+void chain_means_ml (MYREAL *thischainmeans, world_fmt * world);
+void chain_means_bayes (MYREAL *thischainmeans, world_fmt * world);
+void  calc_chain_s(MYREAL *cs, MYREAL *cm, world_fmt *world, long replicate);
+void convergence_progress(FILE *file, world_fmt *world);
+void methods(world_fmt *world);
+void citations(world_fmt *world);
+void convergence_check (world_fmt * world, boolean progress);
+void convergence_check_bayes (world_fmt *world,  long maxreplicate);
+//##
 
 
 
 //public functions
 ///
 /// convergence indicator for ML runs
-void
-convergence_check (world_fmt * world, boolean progress)
+
+void convergence_check (world_fmt * world, boolean progress)
 {
     static MYREAL *lastchainmeans, *chainmeans, *thischainmeans;
     static MYREAL *gelmanw, *gelmanb, *gelmanr;
@@ -121,7 +137,7 @@ convergence_check (world_fmt * world, boolean progress)
             gelmanr = (MYREAL *) mycalloc (len, sizeof (MYREAL));
         }
         n = -1; // a dummy value because the gelman_ functions expect a dummy last value
-        memset (thischainmeans, 0, sizeof (MYREAL) * len);
+        memset (thischainmeans, 0, sizeof (MYREAL) * (size_t) len);
         if (first)
         {
             first = FALSE;
@@ -140,13 +156,14 @@ convergence_check (world_fmt * world, boolean progress)
             calc_gelmanr (gelmanr, gelmanw, gelmanb, len, lastn, n);
             calc_average_biggest_gelmanr (gelmanr, len, &world->convergence->gelmanmeanRall,
                                           &world->convergence->gelmanmaxRall);
-            memcpy (lastchainmeans, thischainmeans, sizeof (MYREAL) * len);
+            memcpy (lastchainmeans, thischainmeans, sizeof (MYREAL) * (size_t) len);
             lastn = n;
         }
     }
 }
 
-void report_values(MYREAL *vec, long len, char text[])
+/*
+static void report_values(MYREAL *vec, long len, char text[])
 {
   long i;
   fprintf(stdout,"%s ",text);
@@ -156,11 +173,10 @@ void report_values(MYREAL *vec, long len, char text[])
     }
   fprintf(stdout,"\n");
 }
-
+*/
 ///
 /// convergence indicator for Bayesian runs
-void
-convergence_check_bayes (world_fmt *world,  long maxreplicate)
+void convergence_check_bayes (world_fmt *world,  long maxreplicate)
 {
     MYREAL *gelmanw, *gelmanb, *gelmanr;
     long len = 0;
@@ -293,6 +309,8 @@ void
 calc_gelmanb (MYREAL *gelmanb, MYREAL *mc, MYREAL *tc, MYREAL *lc, long len,
               long lastn, long n)
 {
+  (void) lastn;
+  (void) n;
     long i;
 
     for (i = 0; i < len; i++)
@@ -572,7 +590,7 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
 ///    ]
 /// The effective sample is calculated as the length the sample n * (1-r)/(1+r)
 /// 
-MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *autoc, MYREAL *effsample)
+MYREAL single_chain_var(world_fmt *world, unsigned long T, MYREAL *variance, MYREAL *autoc, MYREAL *effsample)
 {
   static double *mean;
   static double *S;
@@ -608,11 +626,11 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
   if(world==NULL)
     {
       n=0;
-      memset(mean,0,nn * sizeof(double));
-      memset(S,0,nn * sizeof(double));
-      memset(r,0,nn * sizeof(double));
-      memset(xold,0,nn * sizeof(double));
-      memset(xstart,0,nn * sizeof(double));
+      memset(mean,0,(size_t) nn * sizeof(double));
+      memset(S,0,(size_t) nn * sizeof(double));
+      memset(r,0,(size_t) nn * sizeof(double));
+      memset(xold,0,(size_t) nn * sizeof(double));
+      memset(xstart,0,(size_t) nn * sizeof(double));
       return 0;
     }
   // syntax so that an init really works
@@ -840,7 +858,7 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
   //return *variance;
 }
 
-boolean max_ess(const MYREAL * ess, const long n, const MYREAL minimum, MYREAL *miness)
+boolean max_ess(const MYREAL * ess, long n, const MYREAL minimum, MYREAL *miness)
 {
   long i;
   long z=0;
@@ -867,6 +885,8 @@ void
 calc_gelmanw (MYREAL *gelmanw, world_fmt * world, MYREAL *mc, MYREAL *tc,
               long len, long lastn, long n)
 {
+  (void) lastn;
+  (void) n;
     long i;
     MYREAL s1, s2;
     for (i = 0; i < len; i++)
@@ -941,7 +961,7 @@ calc_allgelmanr (MYREAL *gelmanr, MYREAL *gelmanw, MYREAL *gelmanb, long *nmeans
       {
 	nn += nmeans[j];
       }
-    nn = ceil((float) nn/maxreplicate);
+    nn = (long) (ceil((float) nn/maxreplicate));
     for (i = 0; i < len; i++)
     {
       sqplus = (nn - 1.) / nn * gelmanw[i] + gelmanb[i];
@@ -1043,11 +1063,12 @@ calc_s (long tthis, MYREAL *tc, world_fmt * world)
         }
     }
 }
+
 ///
 /// calculate the variance of a chain tc is the parameter average 
 /// by supplying the length of the chain
-MYREAL
-calc_s2 (long tthis, MYREAL *tc, world_fmt * world, long T)
+/*
+static MYREAL calc_s2 (long tthis, MYREAL *tc, world_fmt * world, long T)
 {
   timearchive_fmt * atl     = &world->atl[world->rep][world->locus];
   long              numpop  = world->numpop;
@@ -1116,6 +1137,7 @@ calc_s2 (long tthis, MYREAL *tc, world_fmt * world, long T)
         }
     }
 }
+*/
 
 ///
 /// calculate the variance of a chain tc is the parameter average 
@@ -1148,8 +1170,7 @@ calc_s_bayes (long tthis, MYREAL *tc, world_fmt * world)
 /// calculates means for the different events on a tree for the Gelman-Rubin statistic
 /// this version of the statistics operates on the compressed treedata and not the parameters
 /// 
-void
-chain_means_ml (MYREAL *thischainmeans, world_fmt * world)
+void chain_means_ml (MYREAL *thischainmeans, world_fmt * world)
 {
   timearchive_fmt * atl     = &world->atl[world->rep][world->locus];
   long              T       = atl->T;
@@ -1192,8 +1213,7 @@ chain_means_ml (MYREAL *thischainmeans, world_fmt * world)
 ///
 /// calculates means for the different parameters for the Gelman-Rubin statistic
 /// for bayesian inference
-void
-chain_means_bayes (MYREAL *thischainmeans, world_fmt * world)
+void chain_means_bayes (MYREAL *thischainmeans, world_fmt * world)
 {
   //  long              T       = world->convergence->chain_counts[world->rep];
   long              T       = world->bayes->numparams;
@@ -1225,7 +1245,7 @@ chain_means (MYREAL *thischainmeans, world_fmt * world)
   if(world->options->bayes_infer)
     {
       temp = (float) (world->convergence->chain_counts[world->rep]!=0) ? world->convergence->chain_counts[world->rep] : 1;  
-      world->convergence->chain_counts[world->rep] = temp;
+      world->convergence->chain_counts[world->rep] = (long) temp;
       chain_means_bayes (thischainmeans, world);
     }
   else
@@ -1240,8 +1260,7 @@ chain_means (MYREAL *thischainmeans, world_fmt * world)
 
 ///
 /// calculates the average over 
-void 
-calc_chain_s(MYREAL *cs, MYREAL *cm, world_fmt *world, long replicate)
+void  calc_chain_s(MYREAL *cs, MYREAL *cm, world_fmt *world, long replicate)
 {
   long len;
   long start;
