@@ -106,7 +106,15 @@ void makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
 
 void init_sequences_aliases (world_fmt * world, option_fmt * options,
                              data_fmt * data, long locus);
+void constrain_rates(long categs, MYREAL *rate, MYREAL *probcat);
+void makeweights_old (world_fmt * world, data_fmt * data, option_fmt *options, long locus);
+void set_nucleotide(MYREAL *treedata, const char nucleotide, const MYREAL *seqerr);
+MYREAL treelike_snp_unlinked (mutationmodel_fmt *s, long xs, world_fmt * world, long locus);
+void copy_seq (world_fmt * original, world_fmt * kopie);
+void find_rates_fromdata_alleles(data_fmt * data, option_fmt * options, world_fmt *world, MYREAL mean);
+void free_seq(seqmodel_fmt **seq, long seqnum);
 
+//##
 
 void check_basefreq (option_fmt * options);
 
@@ -114,47 +122,6 @@ extern void swap (contribarr *a, contribarr *b);
 
 
 
-/* allocation things */
-void
-init_sequences_old (world_fmt * world, option_fmt * options, data_fmt * data,
-                long locus)
-{
-    long sites = world->data->seq[0]->sites[locus];
-    if (options->datatype == 'u')
-        sites *= 5;
-    if (options->datatype == 'n')
-        sites += 4;
-    if (!world->data->seq[0]->done || world->data->seq[0]->alias == NULL)
-    {
-        world->data->seq[0]->done = TRUE;
-        world->data->seq[0]->alias = (long *) mycalloc (1, sizeof (long) * sites);
-        world->data->seq[0]->ally = (long *) mycalloc (1, sizeof (long) * sites);
-        world->data->seq[0]->savealiasweight = (double *) mycalloc (sites, sizeof (double));
-        world->data->seq[0]->aliasweight = (double *) mycalloc (1, sizeof (double) * sites);
-        world->data->seq[0]->location = (long *) mycalloc (1, sizeof (long) * sites);
-        world->data->seq[0]->category = (long *) mycalloc (1, sizeof (long) * sites);
-        world->data->seq[0]->weight = (short *) mycalloc (1, sizeof (short) * sites);
-    }
-    else
-    {
-        world->data->seq[0]->alias =
-            (long *) myrealloc (world->data->seq[0]->alias, sizeof (long) * sites);
-        world->data->seq[0]->ally =
-            (long *) myrealloc (world->data->seq[0]->ally, sizeof (long) * sites);
-        world->data->seq[0]->savealiasweight =
-            (double *) myrealloc (world->data->seq[0]->savealiasweight,
-                              sizeof (double) * sites);
-        world->data->seq[0]->aliasweight =
-            (double *) myrealloc (world->data->seq[0]->aliasweight,
-                              sizeof (double) * sites);
-        world->data->seq[0]->location =
-            (long *) myrealloc (world->data->seq[0]->location, sizeof (long) * sites);
-        world->data->seq[0]->category =
-            (long *) myrealloc (world->data->seq[0]->category, sizeof (long) * sites);
-        world->data->seq[0]->weight =
-            (short *) myrealloc (world->data->seq[0]->weight, sizeof (short) * sites);
-    }
-}
 
 void
 init_sequences_aliases (world_fmt * world, option_fmt * options,
@@ -181,7 +148,7 @@ initratio (option_fmt * options)
         options->ttratio[z++] = atof (tmp);
         tmp = strtok (NULL, " ,;\n");
         options->ttratio =
-            (MYREAL *) myrealloc (options->ttratio, sizeof (MYREAL) * (z + 1));
+	  (MYREAL *) myrealloc (options->ttratio, sizeof (MYREAL) * (size_t) (z + 1));
         options->ttratio[z] = 0.0;
     }
 }
@@ -466,8 +433,7 @@ getbasefreqs (option_fmt * options, seqmodel_fmt * seq, long locus)
 
 /*===================================================*/
 
-void
-makeweights_old (world_fmt * world, data_fmt * data, option_fmt *options, long locus)
+void makeweights_old (world_fmt * world, data_fmt * data, option_fmt *options, long locus)
 {
     /* make up weights vector to avoid duplicate computations */
     long i;
@@ -495,7 +461,7 @@ makeweights_old (world_fmt * world, data_fmt * data, option_fmt *options, long l
             seq->alias[i - 1];
     }
     init_sequences2_old (world, seq, locus);
-    memcpy(seq->savealiasweight, seq->aliasweight, sizeof(long) * seq->endsite);
+    memcpy(seq->savealiasweight, seq->aliasweight, sizeof(long) * (size_t) seq->endsite);
 }    /* makeweights */
 
 void
@@ -537,7 +503,7 @@ makeweights (world_fmt * world, data_fmt * data, option_fmt *options, long locus
             s->alias[i - 1];
 	}
       init_sequences2 (world, s);
-      memcpy(s->savealiasweight, s->aliasweight, sizeof(long) * s->numpatterns);
+      memcpy(s->savealiasweight, s->aliasweight, sizeof(long) * (size_t) s->numpatterns);
       set_siterates(sublocus,world,options);
     }
 }    /* makeweights */
@@ -545,6 +511,7 @@ makeweights (world_fmt * world, data_fmt * data, option_fmt *options, long locus
 void
 init_sequences2_old (world_fmt * world, seqmodel_fmt * seq, long locus)
 {
+  (void) locus;
     if (world->contribution == NULL)
       {
         world->contribution =
@@ -562,6 +529,8 @@ init_sequences2_old (world_fmt * world, seqmodel_fmt * seq, long locus)
 void
 init_sequences2 (world_fmt * world, mutationmodel_fmt * s)
 {
+  (void) world;
+
     if (s->contribution == NULL)
       {
         s->contribution =
@@ -720,8 +689,8 @@ sitesort2_old (world_fmt * world, data_fmt * data, option_fmt *options, long sit
     long *tempsum, *temppop;
     long numind;
     MYREAL a1,a2;
-    tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
-    temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
+    tempsum = (long *) mycalloc (data->numpop, sizeof (long));
+    temppop = (long *) mycalloc (data->numpop, sizeof (long));
     for (i = 0; i < data->numpop; i++)
     {
       if(options->randomsubset > 0)
@@ -783,7 +752,7 @@ sitesort2_old (world_fmt * world, data_fmt * data, option_fmt *options, long sit
                     flip =
                         (a1 > a2);
                     tied = (tied
-                            && a1 == a2);
+                            && (fabs(a1-a2) <= FLT_EPSILON)); 
                     k++;
                 }
                 if (!flip)
@@ -791,7 +760,7 @@ sitesort2_old (world_fmt * world, data_fmt * data, option_fmt *options, long sit
                 itemp = seq->alias[j - 1];
                 seq->alias[j - 1] = seq->alias[j + gap - 1];
                 seq->alias[j + gap - 1] = itemp;
-                itemp = seq->aliasweight[j - 1];
+                itemp = (long) seq->aliasweight[j - 1];
                 seq->aliasweight[j - 1] = seq->aliasweight[j + gap - 1];
                 seq->aliasweight[j + gap - 1] = itemp;
                 j -= gap;
@@ -813,8 +782,8 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
   long numind;
   MYREAL a1,a2;
   long sumtips = 0;
-  tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
-  temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
+  tempsum = (long *) mycalloc (data->numpop, sizeof (long));
+  temppop = (long *) mycalloc (data->numpop, sizeof (long));
   for (i = 0; i < data->numpop; i++)
     {
 
@@ -885,7 +854,7 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
 			flip =
 			  (a1 > a2);
 			tied = (tied
-				&& a1 == a2);
+				&& (fabs(a1-a2) <= FLT_EPSILON)) ;
 		      }
                     k++;
                 }
@@ -894,7 +863,7 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
                 itemp = s->alias[j - 1];
                 s->alias[j - 1] = s->alias[j + gap - 1];
                 s->alias[j + gap - 1] = itemp;
-                itemp = s->aliasweight[j - 1];
+                itemp = (long) s->aliasweight[j - 1];
                 s->aliasweight[j - 1] = s->aliasweight[j + gap - 1];
                 s->aliasweight[j + gap - 1] = itemp;
                 j -= gap;
@@ -916,8 +885,8 @@ sitecombine2_old (world_fmt * world, data_fmt * data, option_fmt *options, long
     long *tempsum, *temppop;
     long numind;
     long kkk;
-    tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
-    temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
+    tempsum = (long *) mycalloc (data->numpop, sizeof (long));
+    temppop = (long *) mycalloc (data->numpop, sizeof (long));
     if(options->randomsubset > 0)
       {
 	tempsum[0] = (options->randomsubset < data->numind[0][locus] ? options->randomsubset : data->numind[0][locus]);
@@ -950,13 +919,13 @@ sitecombine2_old (world_fmt * world, data_fmt * data, option_fmt *options, long
         tied = TRUE;
         while (j <= sites && tied)
         {
-            samewt = ((seq->aliasweight[i - 1] != 0)
-                      && (seq->aliasweight[j - 1] != 0))
-                     || ((seq->aliasweight[i - 1] == 0)
-                         && (seq->aliasweight[j - 1] == 0));
+            samewt = ((seq->aliasweight[i - 1] > FLT_EPSILON)
+                      && (seq->aliasweight[j - 1] > FLT_EPSILON))
+                     || ((seq->aliasweight[i - 1] < FLT_EPSILON)
+                         && (seq->aliasweight[j - 1] < FLT_EPSILON));
             tied = samewt
-                   && (seq->category[seq->alias[i - 1] - 1] ==
-                       seq->category[seq->alias[j - 1] - 1]);
+	      && (seq->category[seq->alias[i - 1] - 1] ==
+			seq->category[seq->alias[j - 1] - 1]);
             k = 0;
             pop = 0;
             kk = -1;
@@ -1009,8 +978,8 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
     long kkk;
     mutationmodel_fmt *s;
     long sumtips = 0;
-    tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
-    temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
+    tempsum = (long *) mycalloc (1, sizeof (long) * (size_t) data->numpop);
+    temppop = (long *) mycalloc (1, sizeof (long) * (size_t) data->numpop);
     if(options->randomsubset > 0)
       {
 	tempsum[0] = (options->randomsubset < data->numind[0][locus] ? options->randomsubset : data->numind[0][locus]);
@@ -1043,13 +1012,13 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
         tied = TRUE;
         while (j <= sites && tied)
         {
-            samewt = ((s->aliasweight[i - 1] != 0)
-                      && (s->aliasweight[j - 1] != 0))
-                     || ((s->aliasweight[i - 1] == 0)
-                         && (s->aliasweight[j - 1] == 0));
+            samewt = ((s->aliasweight[i - 1] > FLT_EPSILON)
+                      && (s->aliasweight[j - 1] > FLT_EPSILON))
+                     || ((s->aliasweight[i - 1] < FLT_EPSILON)
+                         && (s->aliasweight[j - 1] < FLT_EPSILON));
             tied = samewt
-                   && (s->category[s->alias[i - 1] - 1] ==
-                       s->category[s->alias[j - 1] - 1]);
+	      && (s->category[s->alias[i - 1] - 1] ==
+		  s->category[s->alias[j - 1] - 1]);
             k = 0;
             pop = 0;
             kk = -1;
@@ -1090,6 +1059,7 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
 void
 sitescrunch2_old (world_fmt * world, long sites, long i, long j, long locus)
 {
+  (void) locus;
     /* move so positively weighted sites come first */
     long itemp;
     boolean done, found;
@@ -1120,7 +1090,7 @@ sitescrunch2_old (world_fmt * world, long sites, long i, long j, long locus)
                     itemp = seq->alias[i - 1];
                     seq->alias[i - 1] = seq->alias[j - 1];
                     seq->alias[j - 1] = itemp;
-                    itemp = seq->aliasweight[i - 1];
+                    itemp = (long) seq->aliasweight[i - 1];
                     seq->aliasweight[i - 1] = seq->aliasweight[j - 1];
                     seq->aliasweight[j - 1] = itemp;
                 }
@@ -1169,7 +1139,7 @@ sitescrunch2 (world_fmt * world, long sites, long i, long j, long sublocus)
                     itemp = s->alias[i - 1];
                     s->alias[i - 1] = s->alias[j - 1];
                     s->alias[j - 1] = itemp;
-                    itemp = s->aliasweight[i - 1];
+                    itemp = (long) s->aliasweight[i - 1];
                     s->aliasweight[i - 1] = s->aliasweight[j - 1];
                     s->aliasweight[j - 1] = itemp;
                 }
@@ -1225,17 +1195,17 @@ inputweights (mutationmodel_fmt * s, data_fmt * data, long chars)
     long i;
 	char input[1024];
 
-    ch = getc (data->weightfile);
+	ch = (char) getc (data->weightfile);
     while (ch == '#')
     {
         FGETS(input, LINESIZE,data->weightfile);
-        ch = getc (data->weightfile);
+        ch = (char) getc (data->weightfile);
     }
     ungetc (ch, data->weightfile);
     for(i=0;i<chars;i++)
       {
 	s->weight[i] = 1;
-        ch = getc (data->weightfile);
+        ch = (char) getc (data->weightfile);
 	
 	if (isdigit ((int) ch))
 	  s->weight[i] = ch - '0';
@@ -1268,17 +1238,17 @@ void inputcategs (long a, long b, mutationmodel_fmt * s, option_fmt * options, d
     long i;
     char input[LINESIZE];
     //int retval;
-    ch = getc (data->catfile);
+    ch = (char) getc (data->catfile);
     while (ch == '#')
     {
         FGETS(input, LINESIZE,data->catfile);
-        ch = getc (data->catfile);
+        ch = (char) getc (data->catfile);
     }
     ungetc (ch, data->catfile);
     fscanf (data->catfile, "%ld", &options->categs);
     s->numcategs = options->categs;
     s->rate =
-        (MYREAL *) myrealloc (s->rate, sizeof (MYREAL) * s->numcategs);
+      (MYREAL *) myrealloc (s->rate, sizeof (MYREAL) * (size_t) s->numcategs);
     for (i = 0; i < options->categs; i++)
     {
 #ifdef USE_MYREAL_FLOAT
@@ -1317,6 +1287,8 @@ void
 empiricalfreqs (world_fmt * world, option_fmt * options, mutationmodel_fmt * s,
                 long sublocus)
 {
+  (void) options;
+  
     /* Get empirical base frequencies from the data */
     long i, j;
     MYREAL summ, suma, sumc, sumg, sumt, w;
@@ -1395,52 +1367,6 @@ initlambda (option_fmt * options)
 
 
 
-void
-init_tbl_old (world_fmt * world, long locus)
-{
-    /* Define a lookup table. Precompute values and print them out in tables */
-    long i, j;
-    MYREAL sumrates;
-    long categs = world->options->categs;
-    long rcategs = world->options->rcategs;
-    world->tbl = (valrec ***) mymalloc (rcategs * sizeof (valrec **));
-    for (i = 0; i < rcategs; i++)
-    {
-        world->tbl[i] = (valrec **) mymalloc (categs * sizeof (valrec *));
-        for (j = 0; j < categs; j++)
-            world->tbl[i][j] = (valrec *) mymalloc (sizeof (valrec));
-    }
-    for (i = 0; i < rcategs; i++)
-    {
-        for (j = 0; j < categs; j++)
-        {
-            world->tbl[i][j]->rat =
-                world->options->rrate[i] * world->options->rate[j];
-            world->tbl[i][j]->ratxi =
-                world->tbl[i][j]->rat * world->data->seq[0]->xi;
-            world->tbl[i][j]->ratxv =
-                world->tbl[i][j]->rat * world->data->seq[0]->xv;
-        }
-    }
-    sumrates = 0.0;
-    for (i = 0; i < world->data->seq[0]->oldsite; i++)
-    {
-        for (j = 0; j < rcategs; j++)
-            sumrates +=
-                world->data->seq[0]->aliasweight[i] * world->options->probcat[j] *
-                world->tbl[j][world->data->seq[0]->
-                              category[world->data->seq[0]->alias[i] - 1] - 1]->rat;
-    }
-    sumrates /= (MYREAL) world->data->seq[0]->sites[locus];
-    for (i = 0; i < rcategs; i++)
-        for (j = 0; j < categs; j++)
-        {
-            world->tbl[i][j]->rat /= sumrates;
-            world->tbl[i][j]->ratxi /= sumrates;
-            world->tbl[i][j]->ratxv /= sumrates;
-        }
-}    /* inittable */
-
 void init_tbl (world_fmt * world, long locus)
 {
     /* Define a lookup table. Precompute values and print them out in tables */
@@ -1519,6 +1445,7 @@ void
 printweights (FILE * outfile, world_fmt * world, option_fmt * options,
               short inc, long chars, short *weight, char *letters)
 {
+  (void) world;
     /* print out the weights of sites */
     long i, j;
     FPRINTF (outfile, "\n    %s are weighted as follows:\n", letters);
@@ -1594,6 +1521,7 @@ print_seqfreqs (FILE * outfile, world_fmt * world, option_fmt * options)
 MYREAL
 treelike_seq (mutationmodel_fmt *s, long sublocus, world_fmt * world, long locus)
 {
+  (void) locus;
     const MYREAL freqa = s->basefreqs[NUC_A];
     const MYREAL freqc = s->basefreqs[NUC_C];
     const MYREAL freqg = s->basefreqs[NUC_G];
@@ -1687,36 +1615,14 @@ treelike_seq (mutationmodel_fmt *s, long sublocus, world_fmt * world, long locus
     return summ;
 }    /* treelikelihood */
 
-void
-snp_invariants_original (contribarr invariants, long endsite, long rcategs,
-                seqmodel_fmt * seq, phenotype x1)
-{
-    long i, j;
-    MYREAL *val;
-    register MYREAL freqa, freqc, freqg, freqt;
-    freqa = seq->basefrequencies[NUC_A];
-    freqc = seq->basefrequencies[NUC_C];
-    freqg = seq->basefrequencies[NUC_G];
-    freqt = seq->basefrequencies[NUC_T];
-
-        memset (invariants, 0, sizeof (contribarr));
-    for (j = 0; j < rcategs; j++)
-      {
-	for (i = endsite; i < endsite + 4; i++)
-	  {
-	    val = x1[i][j];
-            invariants[j] += 
-	      (freqa * val[0] + freqc * val[1] +
-	       freqg * val[2] + freqt * val[3]);
-	  }
-      }
-    for (j = 0; j < rcategs; j++)
-      invariants[j] = 1. - invariants[j];
-}
 
 void
 snp_invariants (mutationmodel_fmt *s, long xs, contribarr invariants, world_fmt *world, long locus, phenotype x1, MYREAL *scale)
 {
+  (void) xs;
+  (void) world;
+  (void) locus;
+
     //worldoption_fmt *opt;
     const long rcategs = s->numsiterates;
     //MYREAL summ;
@@ -1863,8 +1769,7 @@ treelike_snp (mutationmodel_fmt *s, long xn, world_fmt * world, long locus)
 }    /* treelike_snp */
 
 
-MYREAL
-treelike_snp_unlinked (mutationmodel_fmt *s, long xs, world_fmt * world, long locus)
+MYREAL treelike_snp_unlinked (mutationmodel_fmt *s, long xs, world_fmt * world, long locus)
 {
     //worldoption_fmt *opt;
 
@@ -1932,15 +1837,14 @@ check_basefreq (option_fmt * options)
 }
 
 
-void
-copy_seq (world_fmt * original, world_fmt * kopie)
+void copy_seq (world_fmt * original, world_fmt * kopie)
 {
-    long sites;
+    size_t sites;
     seqmodel_fmt *kseq;
     seqmodel_fmt *oseq;
     kseq = kopie->data->seq[0];
     oseq = original->data->seq[0];
-    sites = oseq->sites[original->locus];
+    sites = (size_t) oseq->sites[original->locus];
     memcpy(kseq->basefrequencies,oseq->basefrequencies,sizeof(MYREAL)*BASEFREQLENGTH);
     kseq->aa = oseq->aa;
     kseq->bb = oseq->bb;
@@ -1949,7 +1853,7 @@ copy_seq (world_fmt * original, world_fmt * kopie)
     kseq->xv = oseq->xv;
     kseq->ttratio = oseq->ttratio;
     kseq->fracchange = oseq->fracchange;
-    memcpy (kseq->sites, oseq->sites, sizeof (long) * original->loci);
+    memcpy (kseq->sites, oseq->sites, sizeof (long) * (size_t) original->loci);
     memcpy (kseq->alias, oseq->alias, sizeof (long) * sites);
     memcpy (kseq->ally, oseq->ally, sizeof (long) * sites);
     memcpy (kseq->category, oseq->category, sizeof (long) * sites);
@@ -1996,7 +1900,7 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options, world_fmt * worl
     }
 
   v = (long **) mycalloc (subloci, sizeof (long *));
-  v[0] = (long *) mycalloc (subloci * maxsites, sizeof (long));
+  v[0] = (long *) mycalloc (subloci * (size_t) maxsites, sizeof (long));
   for (i = 1; i < subloci; i++)
     {
       v[i] = v[0] + maxsites * i;
@@ -2104,6 +2008,7 @@ void find_rates_fromdata(data_fmt * data, option_fmt * options, world_fmt * worl
 
 void find_rates_fromdata_alleles(data_fmt * data, option_fmt * options, world_fmt *world, MYREAL mean)
 {
+  (void) world;
   long locus;
   options->segregs = (long *) mycalloc(data->loci, sizeof(long));
   for (locus=0;locus < data->loci; locus++)
