@@ -53,6 +53,40 @@ skyline plots of Rambaut, Strimmer etc) and also will print a table/file with va
 #else
 extern int myID;
 #endif
+MYREAL waiting_theta(long pop, 
+		     MYREAL *param, 
+		     MYREAL * mig0list, 
+		     long *lineages, 
+		     MYREAL t0, MYREAL t1, 
+		     MYREAL inv_mu_rate,
+		     long numpop, world_fmt *world);
+MYREAL waiting_M(long pop,long to, 
+		 MYREAL *param, 
+		 MYREAL * mig0list, 
+		 long *lineages, 
+		 MYREAL t0, MYREAL t1, 
+		 MYREAL inv_mu_rate,
+		 long numpop, world_fmt *world, boolean usem);
+
+MYREAL waiting_D(long pop,long to, 
+		 MYREAL *param, 
+		 MYREAL * mig0list, 
+		 long *lineages, 
+		 MYREAL t0, MYREAL t1, 
+		 MYREAL inv_mu_rate,
+		 long numpop, world_fmt *world);
+void weighted_average(float xn, float wn, float *xo, float *wo, 
+		      float *sumweight, float *mn, float *mo, 
+		      float *var, float *n, float *r);
+void average(float x, float *mean, float *var, float *n);
+void calc_bin_average(tetra *bin, float val, float weight);
+void print_expected_values_list(FILE *file, long locus, tetra **eventbins, MYREAL eventbinsize, long *eventbinnum, world_fmt *world);
+void read_expected_values_fromfile(FILE *file, world_fmt *world);
+void print_expected_values_tofile(FILE *file,  world_fmt *world);
+void prepare_expected_values(world_fmt *world);
+void print_expected_values_title(FILE *file, boolean progress);
+//##
+
 
 ///
 /// calculate the expected Theta for a coalescence event and returns the expected value
@@ -135,6 +169,9 @@ MYREAL waiting_D(long pop,long to,
 		 MYREAL inv_mu_rate,
 		 long numpop, world_fmt *world)
 {
+  (void) pop;
+  (void) to;
+  (void) inv_mu_rate;;
   long i;
   //long kpop;
   MYREAL expected = 0.0;
@@ -208,7 +245,7 @@ void weighted_average(float xn, float wn, float *xo, float *wo,
     {
       *n += 1;
       temp = wn + *sumweight;
-      invtemp = 1. / temp;
+      invtemp = (float) 1. / temp;
       delta = xn - *mn;
       *var += *sumweight * wn * delta * delta * invtemp;
       *mn += delta*wn * invtemp;
@@ -301,7 +338,7 @@ void calculate_expected_values(tetra **eventbins,
 
   long firstbin = (long) ((age - interval) * inv_eventinterval);
   long bin     = (long) (age * inv_eventinterval);
-  float binage  = eventinterval * bin; //this is on the left side of the bin
+  float binage  = (float) (eventinterval * bin); //this is on the left side of the bin
   MYREAL firstbinage        = eventinterval * firstbin; //this is the age at the left side of first bin
   tetra *bins=NULL;
 
@@ -318,9 +355,9 @@ void calculate_expected_values(tetra **eventbins,
   if(from == to)
     {
       diff = bin - firstbin;
-      weight1 = interval * inv_eventinterval; // or =lweight=1.0
+      weight1 = (float) (interval * inv_eventinterval); // or =lweight=1.0
       pop  = to;
-      val = waiting_theta(pop,world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world); 
+      val = (float) waiting_theta(pop,world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world); 
       if(val <= 0.0)
 	return;
     } 
@@ -331,12 +368,12 @@ void calculate_expected_values(tetra **eventbins,
       if(type != 'd' && type !='D')
 	{
 	  pop = mm2m(from, to, world->numpop);
-	  val = waiting_M(pop, to, world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world, usem); 
+	  val = (float) waiting_M(pop, to, world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world, usem); 
 	}      
       else
 	{
 	  pop = mm2d(from,to,world);
-	  val = waiting_D(pop, to, world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world); 
+	  val = (float) waiting_D(pop, to, world->param0,world->mig0list, lineages,t0,t1, inv_mu_rate, numpop, world); 
 	}
 
 
@@ -375,21 +412,21 @@ void calculate_expected_values(tetra **eventbins,
       // the interval crosses a single bin boundary
       // older bin
       //      weight1 = (age - binage) * inv_eventinterval; 
-      weight1 = (-age + interval + firstbinage + eventinterval) * inv_eventinterval;
+      weight1 = (float) ((-age + interval + firstbinage + eventinterval) * inv_eventinterval);
       calc_bin_average(&bins[firstbin], val, weight1);
       // newer bin
-      weight2 = (age - binage) * inv_eventinterval;
+      weight2 = (float) ((age - binage) * inv_eventinterval);
       calc_bin_average(&bins[bin], val, weight2);
       break;
     default:
       // start and stop are in different bins and more than one boundary apart
-      weight1 = (-age + interval + firstbinage + eventinterval) * inv_eventinterval;
+      weight1 = (float) ((-age + interval + firstbinage + eventinterval) * inv_eventinterval);
       calc_bin_average(&bins[firstbin], val, weight1);
       for(i=firstbin+1; i < bin; i++)
 	{
 	  calc_bin_average(&bins[i], val, 1.0);
 	}
-      weight2 = (age - binage) * inv_eventinterval;
+      weight2 = (float) ((age - binage) * inv_eventinterval);
     calc_bin_average(&bins[bin], val, weight2);
     }
   //  printf("@%c %li %li :%li:  %f %f %f %f %f %f %f\n", from==to ? 'c' : 'm', from, to, bin, val, age, bins[bin][0],bins[bin][1], lweight, weight1, weight2); 
@@ -411,9 +448,9 @@ void calculate_expected_values(tetra **eventbins,
 /// 6)
 /// 7)
 /// 8)
-void
-setup_expected_events (world_fmt * world, option_fmt * options)
+void setup_expected_events (world_fmt * world, option_fmt * options)
 {
+  (void) options;
   long locus, i, j,z;
     long allocsize = 1;
     long npall = world->numpop2+world->species_model_size * 2 + world->bayes->mu;
@@ -526,7 +563,7 @@ void read_expected_values_fromfile(FILE *file, world_fmt *world)
   long * allocsize;
   long npall = world->numpop2+world->species_model_size * 2 + world->bayes->mu;
 
-  allocsize = (long *) mycalloc(npall*world->loci,sizeof(long));
+  allocsize = (long *) mycalloc((size_t) (npall*world->loci),sizeof(long));
   for(i=0;i<npall*world->loci;i++)
     {
       allocsize[i]=1;
@@ -561,12 +598,12 @@ void read_expected_values_fromfile(FILE *file, world_fmt *world)
 	      allocsize[spacer + pop] += SOME_ELEMENTS;
 	      eventbins[pop] = (tetra *) myrealloc(eventbins[pop], allocsize[spacer + pop] * sizeof(tetra));
 	    }
-	  eventbins[pop][i][0] = atof(strsep(&inptr,"\t"));
-	  eventbins[pop][i][1] = atof(strsep(&inptr,"\t"));
-	  eventbins[pop][i][2] = atof(strsep(&inptr,"\t"));
-	  eventbins[pop][i][3] = 0;
-	  eventbins[pop][i][4] = atof(strsep(&inptr,"\t"));
-	  eventbins[pop][i][5] = atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][0] = (float) atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][1] = (float) atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][2] = (float) atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][3] = 0.0f;
+	  eventbins[pop][i][4] = (float) atof(strsep(&inptr,"\t"));
+	  eventbins[pop][i][5] = (float) atof(strsep(&inptr,"\t"));
 	}
     }
   myfree(allocsize);
@@ -730,14 +767,14 @@ void prepare_expected_values(world_fmt *world)
 		  else
 		    eventbins[pop][i][5] = 0.0;
 		  rs = eventbins[pop][i][5];//autocorrelation
-		  rs = eventbins[pop][i][4] * (1.-rs)/(1.+rs);// artificial value correcting for correlation 
+		  rs = (float) (eventbins[pop][i][4] * (1.-rs)/(1.+rs));// artificial value correcting for correlation 
 		  // rs is the number of observation in bin
 		  // standard deviation corrected with autocorrelation
 		  // rs is number of obersvations the formula below
 		  // assumes that eventbins[][][1] is the average weight and not the sumweight
 		  // because originally to formula calls for *= rs/((rs-1) sumweight)
 		  // here we do rs/((rs-1) rs * weightaverage)
-		  if (rs-1.0 == 0.0)
+		  if (fabs(rs-1.0f) < FLT_EPSILON)
 		    eventbins[pop][i][2] = -999.0;
 		  else
 		    eventbins[pop][i][2] *= 1./((rs-1.) * eventbins[pop][i][1]);
@@ -753,14 +790,14 @@ void prepare_expected_values(world_fmt *world)
 		    }
 		  else
 		    {
-		      eventbins[pop][i][2] = sqrt(eventbins[pop][i][2])/sqrt(eventbins[pop][i][4]);
+		      eventbins[pop][i][2] = (float) (sqrt(eventbins[pop][i][2])/sqrt(eventbins[pop][i][4]));
 		    }
 		  // calculate standard deviations of weights (this were unweighted)
 		  // this seems only adjust for sample versus population but this was done before see up
 		  if (eventbins[pop][i][4]-1. != 0.0)
 		    {
 		      eventbins[pop][i][3] *= eventbins[pop][i][4]/(eventbins[pop][i][4]-1.); 
-		      eventbins[pop][i][3] = sqrt(eventbins[pop][i][3]);
+		      eventbins[pop][i][3] = (float) (sqrt(eventbins[pop][i][3]));
 		    }
 		  else
 		    eventbins[pop][i][3] = HUGE;
@@ -867,6 +904,7 @@ void print_expected_values_title(FILE *file, boolean progress)
 
 void print_expected_values(world_fmt * world, option_fmt *options)
 {
+  (void) options;
   long locus;
   long sumloc = (world->loci > 1) ? 1 : 0;
   long npall = world->numpop2 + world->bayes->mu + world->species_model_size * 2;
