@@ -74,7 +74,18 @@ stick is arbitrary in size, too small to much work, too large to much work
 extern int myID;
 #endif
 extern MYREAL norm (MYREAL *d, long size);
-
+// functions
+void set_slice_param(MYREAL newparam, long which, world_fmt * world);
+void set_slice_param_timek(MYREAL newparam, long which, world_fmt * world);
+void set_multi_slice_param(MYREAL *newparam, long numparam, world_fmt * world);
+void random_direction(MYREAL *coord,long dim);
+void sphere_random(MYREAL *lower, MYREAL *values, MYREAL *upper, 
+		   MYREAL *r, MYREAL stick, long numparam, MYREAL *minparam, MYREAL *maxparam);
+void sphere_x_random(MYREAL *lower, MYREAL *values, MYREAL *upper, 
+		     MYREAL *r, long numparam, MYREAL * minparam, MYREAL * maxparam);
+void add_stick(MYREAL *values, MYREAL stick, MYREAL *r, long numparam, MYREAL * minparam, MYREAL * maxparam);
+//##
+// functions implementation
 void set_slice_param(MYREAL newparam, long which, world_fmt * world)
 {
   MYREAL oldparam;
@@ -126,10 +137,11 @@ void set_slice_param_timek(MYREAL newparam, long which, world_fmt * world)
 
 void set_multi_slice_param(MYREAL *newparam, long numparam, world_fmt * world)
 {
+  (void) numparam;
   MYREAL oldparam;
   long numpop2 = world->numpop2;  
   // set new parameters and allow for custom migration matrix
-  memcpy(world->param0,newparam,sizeof(MYREAL)*numpop2);
+  memcpy(world->param0,newparam,sizeof(MYREAL)*(size_t) numpop2);
   precalc_world(world);
   if(world->bayes->mu)
     {
@@ -324,7 +336,7 @@ MYREAL sliceRatio (MYREAL *startval, long which, world_fmt * world, MYREAL  (*fu
       }*/
   w=which;
       // if user chose prior bounds that essentially fix value simple return old log(prob)
-  if(maxparam ==  minparam)
+  if(fabs(maxparam - minparam) > FLT_EPSILON)
     {
        return world->bayes->oldval;
     }
