@@ -41,7 +41,7 @@ $Id: tools.h 2157 2013-04-16 22:27:40Z beerli $
 // true should continue/shortcut loop
 // false should do the rest of the loop, and reset j0 to j
 							  
-extern void clearscreen();
+extern void clearscreen(void);
 
 extern boolean shortcut(long j0,bayes_fmt *bayes, long *j);
 extern int finddigits(long number);
@@ -174,6 +174,7 @@ extern char *sgets_safe (char **s, long *size, char **stream);
 /* non-system erf functions */
 extern double myerf(double x);
 extern double myerfc(double x);
+extern double erfinv(double x);
 extern double inverse_cumstd_normal(double p);
 
 #ifdef CAUTIOUS
